舰船类型 - 舰R百科
Date: 2022-09-10T11:19:04Z

百科即日起逐步启用webp格式图片，如遇到图片显示不正确，请更新或更换浏览器。(哪款浏览器支持webp？)
您好，这里是战舰少女R的民间非官方百科，可以查阅战舰少女的相关资料，也欢迎您一起来完善百科。一切编辑行为都是可以恢复的，请大胆编写。

# 舰船类型

来自舰R百科
跳到导航 跳到搜索

新手指引

- 新手入门
- 海域资料
- 历史战役
- 远征
- 任务
- 好感度与损管
- 战利品

进阶资料

- 装备图鉴
- 技能
- 战斗机制
- 港区系统
- 舰娘获取
- 装备获取

舰娘图鉴

- 按编号
- 按类型
- 按国别
- 出身
- 归宿
- 换装图鉴
- 深海舰队

游戏动态

- 卫星观测
- 历次场刊
- 运营历史
- 参与画师
- 配音演员

同人创作

- 同人影视
- 同人漫画
- 同人游戏
- 同人小说
- 周年贺图集

杂学考据

- 考据勘误汇总
- 游戏BUG
- 历代登录界面
- 港区
- 勋章
- 头像
- 音乐鉴赏
- 黑话词典
- 舰名溯源
- 特殊成就
- 物品道具
- 历次活动关卡图标
- 小剧场

《战舰少女R》中的舰娘分为多个种类，分别来自历史中的舰船种类。目前已经实装并且可被玩家使用的有战列舰（BB）、战列巡洋舰（BC）、航空战列舰（BBV）、导弹战列舰（BBG）、轻型航母（CVL）、航空母舰（CV）、装甲航母（AV）、轻巡洋舰（CL）、重巡洋舰（CA）、重雷装巡洋舰（CLT）、航空巡洋舰（CAV）、导弹大型巡洋舰（CBG）、驱逐舰（DD）、导弹驱逐舰（ASDG）、防空导弹驱逐舰（AADG）、浅水重炮舰（BM）、潜水艇（SS）、重炮潜艇（SC）、补给舰（AP）。早期还存在水上机母舰（AV）分类，后被取消。今后还将实装潜水航母等舰种。

除了以上分类外，游戏内还有另外两种舰船分类方法：

1.按照吨位分类

  按照舰船的吨位从大到小分成三个级别，分别是大型舰，中型舰和小型舰。这个分类影响舰船的闪避，以及防空属性，大型舰拥有更高的减伤收益的防空属性，中型舰拥有相对平衡的减伤收益和闪避收益的防空属性，小型舰拥有更高的闪避收益的防空属性。
  大型舰包括：战列舰（BB）、战列巡洋舰（BC）、航空战列舰（BBV）、导弹战列舰（BBG）、导弹大型巡洋舰（CBG）、航空母舰（CV）、装甲航母（AV）
  中型舰包括：轻巡洋舰（CL）、重巡洋舰（CA）、重雷装巡洋舰（CLT）、航空巡洋舰（CAV）、轻型航母（CVL）
  小型舰包括：驱逐舰（DD）、导弹驱逐舰（ASDG）、防空导弹驱逐舰（AADG）、浅水重炮舰（BM）、潜水艇（SS）、重炮潜艇（SC）、补给舰（AP）

2.按照用途分类

  按照各个舰种在实战中的用途进行分类，分为主力舰、护卫舰和水下舰三种。这个分类影响航向分配的航速计算。护卫舰在轮型阵时会发动防空弹幕，在梯形阵时会锁定敌方对位非水下舰单位（会在对位敌舰上出现准心图案），降低其50%闪避率。
  主力舰包括：战列舰（BB）、战列巡洋舰（BC）、航空战列舰（BBV）、导弹战列舰（BBG）、导弹大型巡洋舰（CBG）、航空母舰（CV）、装甲航母（AV）、导弹驱逐舰（ASDG）
  护卫舰包括：驱逐舰（DD）、防空导弹驱逐舰（AADG）、轻巡洋舰（CL）、重巡洋舰（CA）、重雷装巡洋舰（CLT）、航空巡洋舰（CAV）、轻型航母（CVL）、浅水重炮舰（BM）、潜水艇（SS）、重炮潜艇（SC）、补给舰（AP）
  水下舰包括：潜水艇（SS）、重炮潜艇（SC）

  注：水下舰属于特殊的一类护卫舰，护卫舰相关的buff对水下舰同样有效，水下舰的特殊之处在于自身对潜值为0的舰船无法攻击水下舰，且梯形阵时水下舰无法被对方锁定，而水下舰可以锁定对位非水下舰单位。

图例：卡片左上角第一个数字表示此舰娘在模拟演习模式中的出击花费，第二个数字表示此舰娘在决战模式中的战略点数基础花费。

## 战列舰 ( 战列 ) / Battleship（BB）[编辑]

### 历史沿革[编辑]

大舰巨炮的典范，装备大口径火炮，拥有厚重的装甲。是曾经的海上霸主和海权的象征，以厚重的装甲和压倒性火力为一切兵器爱好者津津乐道，战列舰之间的直接对决更是令人热血沸腾。但是，随着航空母舰和舰载航空兵的发展，还有经过几次以航母为主力的战役，各国海军逐渐认识到了战列舰的局限性，发展重心慢慢向航母转移，巨舰大炮日渐式微。步入冷战时代，反舰导弹等能够精确制导的超视距武器出现，传统的大舰巨炮没有优势，各国便不再发展战列舰，战列舰这一海上霸主逐渐在人们视野中淡去。2001年，世界上最后一艘战列舰衣阿华号退役封存。

### 游戏性能[编辑]

战列舰在游戏中拥有最高的火力、装甲和血量但也混进了改造前的爱莉这种54HP的最强重炮。，是攻克高难度关卡的主力，同时配合各种技能能够对敌方所有水面舰艇造成巨大伤害，战列舰和战列巡洋舰统称为“大炮”。除了类似于选择技能“凯旋之歌”的黎塞留等极个别情况，大炮的普遍装备配置为“三炮一弹”，即四个格子装备三门主炮加一枚91式穿甲弹。

虽然在现代海军里战列舰早已被作战半径更广的航母和精确制导武器所取代，但在游戏里的活动高难度关卡攻坚战中，战列舰仍然是首选的主力舰种，因为游戏内战列舰数量众多，多个主要国家阵营都有战列舰以防带路条件和功勋任务限制国籍，覆盖全面，而且更重要的是每个主要阵营都有强力且很好用的战列舰。

但强力也是要付出代价的，战列舰出击和维修消耗也是所有舰种中最高的，所以一般来说不打活动的日常任务里战列舰都是不会派上场的，即便是练级通常也只会在演习中练级。

战列舰在水面虽然称王称霸，但她们无法反潜和开幕，以及其较低的回避值在潜艇的鱼雷面前非常脆弱潜艇：听说你是战列舰？，但凭借自身较高的防空和装甲值对航空攻击也有一定抵御能力。

战斗流程

阶段 | BUFF | 航空战 | 导弹战 | 先制反潜 | 先制鱼雷 | 炮击战·首轮炮击 | 炮击战·次轮炮击 | 鱼雷战 | 闭幕导弹 | 夜战
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否参与 | 是 | 否 | 否 | 否 | 否 | 是 | 是 | 否[1] | 否 | 是
备注 | 如果有的话 |  |  |  |  |  |  | 未大破才能参与 |  | 未大破才能参与

装备类型

装备槽数量(改前→改后)：4→4
装备种类 | 小型主炮 | 中型主炮 | 大型主炮 | 副炮 | 鱼雷 | 攻击机·战斗机·轰炸机 | 侦察机 | 雷达 | 炮弹 | 防空炮 | 反潜装备 | 发射器·导弹
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否可装备 | 是 | 是 | 是 | 是 | 否[1] | 否 | 是 | 是 | 是 | 是 | 否 | 否
备注 |  |  |  |  |  |  | 需有搭载量 | 不可装备声呐 |  |  |  |
不可装备的强化部件 | 铁锚、附加装甲(中型)、发烟筒

1. ↑ 跳转至： 1.0 1.1 战列舰中仅改造后的提尔比茨可以装备鱼雷并参与鱼雷战。

图鉴

2 2
No. 2
扶桑
2 2
No. 3
山城
2 2
No. 4
伊势
2 2
No. 5
日向
3 3
No. 6
俾斯麦
3 3
No. 7
提尔比茨
3 3
No. 8
纳尔逊
3 3
No. 9
罗德尼
3 3
No. 10
威尔士亲王
2 2
No. 11
内华达
2 2
No. 12
俄克拉荷马
2 2
No. 13
安德烈亚·多利亚
4 4
No. 100
狮(战列舰)
3 3
No. 101
长门
3 3
No. 102
陆奥
2 2
No. 103
皇家橡树
2 2
No. 104
厌战
3 3
No. 105
前卫
2 2
No. 106
田纳西
2 2
No. 107
加利福尼亚
3 3
No. 108
科罗拉多
3 3
No. 109
马里兰
3 3
No. 110
西弗吉尼亚
3 3
No. 111
华盛顿
3 4
No. 112
维内托
6 5
No. 113
黎塞留
4 4
No. 200
兴登堡
2 2
No. 203
伊丽莎白女王
4 3
No. 205
约克公爵
4 4
No. 206
北卡罗来纳
5 5
No. 207
南达科他(BB-57)
4 4
No. 208
马萨诸塞
6 6
No. 209
密苏里
4 4
No. 210
衣阿华
2 2
No. 211
卡约·杜伊里奥
3 3
No. 213
罗马
3 3
No. 214
苏联
2 2
No. 216
敦刻尔克
2 2
No. 217
斯特拉斯堡
2 2
No. 299
让巴尔
3 3
No. 305
英王乔治五世
5 5
No. 345
威斯康星
1 2
No. 355
联合力量
6 6
No. 367
乌尔里希·冯·胡滕
5 5
No. 380
圣乔治
2 2
No. 381
印第安纳
2 2
No. 396
新墨西哥
4 4
No. 409
新泽西
5 4
No. 418
阿金库尔
3 2
No. 442
里昂
4 3
No. 448
弗兰德尔
4 4
No. 450
L20
5 6
No. 454
征服者
3 2
No. 460
宾夕法尼亚
2 4
No. 464
南达科他(BB-49)
2 2
No. 468
猎户座
2 2
No. 478
阿方索十三世
2 5
No. 499
克里蒙梭
5 5
No. 506
1938(I)
5 5
No. 514
近江
6 6
No. 520
蒙大拿
2 2
No. 532
但丁

改造

4 3
No. 1003
山城
4 4
No. 1006
俾斯麦
4 4
No. 1007
提尔比茨
4 4
No. 1008
纳尔逊
4 4
No. 1009
罗德尼
3 3
No. 1010
威尔士亲王
2 2
No. 1011
内华达
2 2
No. 1012
俄克拉荷马
3 3
No. 1013
安德烈亚·多利亚
4 3
No. 1014
金刚
7 6
No. 1100
狮(战列舰)
4 4
No. 1101
长门
4 4
No. 1102
陆奥
4 4
No. 1105
前卫
3 2
No. 1106
田纳西
3 2
No. 1107
加利福尼亚
4 4
No. 1108
科罗拉多
5 5
No. 1109
马里兰
5 5
No. 1110
西弗吉尼亚
4 4
No. 1111
华盛顿
6 6
No. 1112
维内托
6 6
No. 1113
黎塞留
6 6
No. 1206
北卡罗来纳
6 6
No. 1207
南达科他(BB-57)
2 3
No. 1211
卡约·杜伊里奥
6 6
No. 1380
圣乔治

## 航空战列舰 ( 航战 ) / Battleship, aviation（BBV）[编辑]

### 历史沿革[编辑]

战列舰与航空母舰的结合，配备战列舰主炮以及具备搭载飞机功能的战舰。尽管世界各国都曾经有过类似的对战列舰改造计划（英国的狮级、法国黎塞留级让•巴尔号、美国的衣阿华级等等），但唯独只有日本真正实行——为了补充在太平洋战争中失去的航母，且暂无足够经费将大型战舰完全改装成航母，故而将旧式战列舰伊势、日向二舰拆除部分主炮，装上航空甲板，世界上唯二的航空战列舰应运而生。又由于各种错误的战术，使得原本预定配属该两舰的航空队损失殆尽，故此伊势级在历史上一次都没有表现过其航空机能，便迎来了战争的终结。因此，航空战列舰的真正实用性能至今为止都饱受争议。

### 游戏性能[编辑]

其中，暴怒号在历史上是由大型轻巡洋舰改造为航战的，但游戏中跳过了该阶段，直接作为航战登场。属性上尽管保留了鱼雷值且能强化，却因为舰种属于航战而无法参加闭幕雷击毫无作用的鱼雷值强化。

航战同时拥有开幕轰炸只能装备水上飞机，且无法享受正航们的各种舰载机buff、昼战两轮炮击威力不如战列或战巡，且大破状态下不参与及反潜的功能只在装备带反潜值的水上飞机的情况下进行次轮炮击阶段的反潜，且中破状态下不参与，“样样通样样松”的完美诠释。

虽然拥有多种攻击方式，但其基础属性不高，而且要装载飞机则必须损失火力，在目前版本比较鸡肋。最大的用途是当地图限制战列舰总数或者限制参战船只国籍时可以替补上场。

战斗流程

阶段 | BUFF | 航空战 | 导弹战 | 先制反潜 | 先制鱼雷 | 炮击战·首轮炮击 | 炮击战·次轮炮击 | 鱼雷战 | 闭幕导弹 | 夜战
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否参与 | 是 | 是 | 否 | 否 | 否 | 是 | 是 | 否 | 否 | 是
备注 | 如果有的话 | 需要搭载战斗机或轰炸机且飞机有剩余、未大破才能参与 |  |  |  |  | 未大破才能参与，未中破且装备具对潜值的舰载机时，在此阶段优先反潜。 |  |  | 未大破才能参与

装备类型

装备槽数量：4
装备种类 | 小型主炮 | 中型主炮 | 大型主炮 | 副炮 | 鱼雷 | 攻击机·战斗机·轰炸机 | 侦察机 | 雷达 | 炮弹 | 防空炮 | 反潜装备 | 发射器·导弹
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否可装备 | 是 | 是 | 是 | 是 | 否 | 是 | 是 | 是 | 是 | 是 | 否 | 否
备注 |  |  |  |  |  | 仅可装备瑞云、晴岚、HE-119、萨博S.17BS、SR.A/1水上战斗机、瑞云12型、黄蜂直升机（AS.12）、H-34直升机（武装）、彗星（誉）、H-34G反潜直升机 |  | 不可装备声呐 |  |  |  |
不可装备的强化部件 | 铁锚、附加装甲(中型)、发烟筒

注：4个装备槽中仅后两个有飞机搭载量，即只有后两个装备槽能装备飞机。

图鉴

2 2
No. 156
暴怒

改造

4 3
No. 1002
扶桑
3 3
No. 1004
伊势
3 3
No. 1005
日向

## 战列巡洋舰 ( 战巡 ) / Battlecruiser（BC）[编辑]

### 历史沿革[编辑]

战列巡洋舰在历史上是争议最多的舰种，一般认为，战列巡洋舰是在无法同时满足火力防护以及机动性的时代，被迫所做出来的一种妥协设计。第一次世界大战时期的战列巡洋舰可视为战列舰牺牲部分防护而取得较高航速的权衡方案，主要职能是利用高航速抢占战列线上的优势位置。在同时能够满足航速与防护要求的高速战列舰出现后，战列巡洋舰迅速被其取代，声望号和胡德号基本上就是战列巡洋舰的巅峰。在一战结束不久，高速战列舰面世之后其实再也没有下水严格意义上的“战列巡洋舰”。

20世纪40年代海军条约失效后，各国在巡洋舰上的军备竞赛再次启动。为了压制条约巡洋舰，受到“德意志”级的启发，各国先后地提出了“巡洋舰杀手”，亦即大型巡洋舰的概念。美国的“阿拉斯加”级、日本的“超甲巡wows中的吉野”计划、以及苏联在战后设计的“斯大林格勒”计划都是这个思路的产物。她们在战场上用于猎杀敌方巡洋舰，并不属于传统战列巡洋舰（对抗敌方战列舰）职能范围。

除了真正的“战列巡洋舰”和“大型巡洋舰”，历史上很多不上不下分类的其他舰种在游戏中皆被算作战巡奇怪分类舰娘收容所。如：

- 大型轻巡洋舰勇敢级。
- 装甲舰/重巡洋舰/破交舰德意志级。
- 快速战列舰/轻型战列舰沙恩霍斯特级。

### 游戏性能[编辑]

游戏中的战巡可以看作战列的劣化版，装备配置和战列基本一致，消耗也普遍比战列低，大多拥有较高的航速以及和战列不相上下的火力，但普遍牺牲了装甲，这也导致战巡在面对航空攻击时的抗性比战列舰要差一些。胡德、星座是相当好用的船，虽然某些战巡由于未改造而在性能上稍稍不尽人意，但在游戏前期依然是大炮编队的有力补充。而且例如十三号战舰、无比等未改战巡都拥有不错的属性和综合实力，在限制国籍和战列舰的任务或带路条件中也是战列舰的同位替代。此外，也不乏凭借出色技能超越普通战列舰的存在，例如无敌人如其名

德意志级、勇敢级可以装备鱼雷。

战斗流程

阶段 | BUFF | 航空战 | 导弹战 | 先制反潜 | 先制鱼雷 | 炮击战·首轮炮击 | 炮击战·次轮炮击 | 鱼雷战 | 闭幕导弹 | 夜战
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否参与 | 是 | 否 | 否 | 否 | 否 | 是 | 是 | 否[1] | 否 | 是
备注 | 如果有的话 |  |  |  |  |  | 射程长或超长可参与次轮炮击 | 未大破才能参与 |  | 未大破才能参与

注：战列巡洋舰中仅德意志级和勇敢级可以装备鱼雷。

装备类型

装备槽数量(改前→改后)：4→4（德意志级为3）
装备种类 | 小型主炮 | 中型主炮 | 大型主炮 | 副炮 | 鱼雷 | 攻击机·战斗机·轰炸机 | 侦察机 | 雷达 | 炮弹 | 防空炮 | 反潜装备 | 发射器·导弹
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否可装备 | 是 | 是 | 是 | 是 | 否[1] | 否 | 是 | 是 | 是 | 是 | 否 | 否
备注 |  |  |  |  |  |  | 需有搭载量 | 不可装备声呐 |  |  |  |
不可装备的强化部件 | 铁锚、附加装甲(中型)、发烟筒

1. ↑ 跳转至： 1.0 1.1 战列巡洋舰德意志级、勇敢级、无比和星座可以参与鱼雷战。

图鉴

3 3
No. 1
胡德
2 2
No. 14
金刚
2 2
No. 15
比睿
2 2
No. 16
榛名
2 2
No. 17
雾岛
2 2
No. 18
声望
2 2
No. 19
反击
2 3
No. 20
阿拉斯加
2 3
No. 21
关岛
2 2
No. 114
沙恩霍斯特
2 2
No. 115
格奈森瑙
2 2
No. 128
德意志
2 2
No. 129
舍尔海军上将
2 2
No. 130
斯佩伯爵海军上将
1 2
No. 154
勇敢
1 2
No. 155
光荣(大型轻巡洋舰)
1 2
No. 318
毛奇
4 5
No. 331
无比
4 5
No. 362
星座
2 2
No. 368
塞德利茨
3 3
No. 397
斯大林格勒
4 5
No. 435
B65
5 5
No. 436
十三号战舰
3 2
No. 446
狮(战列巡洋舰)
6 5
No. 461
无敌
2 2
No. 484
安森
2 2
No. 490
克劳塞维茨
2 3
No. 524
夏威夷

0 2
No. 8116
戈本

改造

6 6
No. 1001
胡德
3 3
No. 1018
声望
2 3
No. 1019
反击
3 3
No. 1130
斯佩伯爵海军上将
6 6
No. 1362
星座

## 导弹战列舰 ( 导战 ) / Battleship, guided missile（BBG）[编辑]

### 历史沿革[编辑]

1950年代，世界步入导弹时代，战列舰的大口径火炮被认为已经落伍。美国在二战结束后仍然保留着舰龄较小的四艘“衣阿华”级战列舰，而这些战列舰很自然地被设想作为导弹发射的平台。在50-60年代，曾有过十多个在“衣阿华”级战列舰上加装防空导弹系统的方案，但最后这些方案都因为不够经济而没有实施。最后，四艘“衣阿华”级还是迎来了暂时封存的命运。到了80年代，随着美国的火炮巡洋舰逐渐退役，海军急需一种对陆攻击的平台，因此此前被封存的四艘战列舰重新进入了海军的视野——她们加装上了“战斧”和“鱼叉”导弹承担了对陆攻击的任务，并在海湾战争中参战。

法国海军也曾于1958年计划将让·巴尔号战列舰进行导弹化改造，甚至一度还有装备弹道导弹的想法，但这些方案由于资金原因最终没有实施。

### 游戏性能[编辑]

注意，目前游戏内的导战均为“反舰型导弹战列舰”，也就是仅有开幕导弹，且不具备导弹拦截能力，和导驱是一样的。

导战有专门的导弹搭载槽，装备了导弹的装备格会在导弹战阶段发射开幕导弹，而在其余阶段导战与战列舰无异。导战必须装备发射器才能参与导弹战，而且导弹对目标进行攻击后，无论是否命中都会消耗。导弹命中极高，而且导战本身火力够高，其导弹伤害甚至超越了轰炸机。

导战的优势是可以达到目前游戏内单舰第二高的攻击频率，为6次（第一是大巡的8次）如果让巴尔·改用一技能偷借走精锐装备、BIGSEVEN、混合特击，可以直追8次，虽然频率不及大巡，但导战的导弹是开幕导弹，其先手价值要比大巡的后手导弹要高得多，而且导战再怎么说也是战列舰，其基础火力是肯定高于大巡的，所以导战既可以装上大炮的装备当作不叫“战列舰”的战列舰来用，又可以全部带上导弹当作会发射导弹的战列舰来用，用途相较于大巡广一些。导战在带满三枚导弹和发射器时拥有开幕三发导弹+两轮炮击战+夜战炮击一共六次攻击频率，搭配导弹的高命中，导战可以在活动要求S胜以及斩杀boss的时候充分发挥高攻击频率的补刀优势；而作为普通战列舰时也毫不逊色，拥有极高的战略价值。

目前游戏中实装了两艘导战。技能提供锁头或者导弹暴击的密苏里属于必练的一线主力。改造后的让巴尔除了二技能的无脑输出外，成为导战后也大幅度提升了一技能的上限。

战斗流程

阶段 | BUFF | 航空战 | 导弹战 | 先制反潜 | 先制鱼雷 | 炮击战·首轮炮击 | 炮击战·次轮炮击 | 鱼雷战 | 闭幕导弹 | 夜战
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否参与 | 是 | 否 | 是 | 否 | 否 | 是 | 是 | 否 | 否 | 是
备注 | 如果有的话 |  | 需要装备发射器和导弹 |  |  |  |  |  |  | 未大破才能参与，攻击方式为炮击

装备类型

装备槽数量(改前→改后)：4→4
装备种类 | 小型主炮 | 中型主炮 | 大型主炮 | 副炮 | 鱼雷 | 攻击机·战斗机·轰炸机 | 侦察机 | 雷达 | 炮弹 | 防空炮 | 反潜装备 | 发射器·导弹
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否可装备 | 是 | 是 | 是 | 是 | 否 | 否 | 是 | 是 | 是 | 是 | 否 | 是
备注 |  |  |  |  |  |  | 需有搭载量 | 不可装备声呐 |  |  |  |
不可装备的强化部件 | 铁锚、附加装甲(中型)、发烟筒

图鉴

改造

7 6
No. 1209
密苏里
2 6
No. 1299
让巴尔

## 导弹大型巡洋舰 ( 大巡 ) / Large Cruiser, guided missile（CBG）[编辑]

### 历史沿革[编辑]

1958年，美国海军曾计划将阿拉斯加级大型巡洋舰改装成为导弹大型巡洋舰。这个改造工程包括拆除舰体后部的炮塔，换装导弹发射架。然而在进一步的计划论证中，这项改造被认为花费过于昂贵，最终没有实施。

### 游戏性能[编辑]

注意，游戏里的“大巡”特指“导弹大型巡洋舰”而不是“大型巡洋舰”，且目前游戏内的大巡除了作为“防空型导弹大型巡洋舰”的阿拉斯加级外，还有就是作为“导弹轻巡洋舰”的加里波第。大巡没有开幕导弹仅有闭幕导弹和夜战导弹，具备导弹拦截能力，和防驱是一样的。

大巡有专门的导弹搭载槽，装备了导弹的装备格会在导弹战阶段对对方的开幕导弹攻击进行拦截。在炮击战阶段大巡与战列舰无异。在鱼雷战结束后，如果仍有导弹余量，则进行闭幕导弹。夜战阶段如果仍有导弹余量，则夜战也进行导弹攻击；若导弹耗完，则进行炮击。装备了几格导弹，就对几个目标进行攻击（目标可重复），分别结算导弹伤害。大巡必须装备发射器才能参与导弹战，而且导弹对目标进行攻击后，无论是否命中都会消耗。导弹命中极高，但伤害不及轰炸机。

大巡的优势是拥有目前游戏内单舰最高的攻击频率，一般大巡的标准装备是一个发射架加上三枚防空导弹极其不推荐大巡带大炮的装备，否则无法发挥出大巡独特的优势，这样一艘大巡拥有两轮炮击战+闭幕三发导弹+夜战三发导弹一共八次攻击频率，搭配导弹的高命中以及道中的导弹拦截能力，大巡可以在活动要求S胜以及斩杀boss的时候充分发挥高攻击频率的补刀优势，本身作为专业的反开幕舰种，也拥有极高的战略价值，所以目前游戏中的阿拉斯加和关岛都属于必练的一线主力。

战斗流程

阶段 | BUFF | 航空战 | 导弹战 | 先制反潜 | 先制鱼雷 | 炮击战·首轮炮击 | 炮击战·次轮炮击 | 鱼雷战 | 闭幕导弹 | 夜战
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否参与 | 是 | 否 | 是 | 否 | 否 | 是 | 是 | 否 | 是 | 是
备注 | 如果有的话 |  | 需要装备发射器和导弹，但仅在对方发射开幕导弹时参与导弹拦截（且防空导弹的拦截值必须高于反舰导弹的突防值才可以拦截成功），不会攻击敌方舰船 |  |  |  |  |  | 未大破才能参与，需要装备发射器和导弹 | 未大破才能参与，攻击方式为导弹

装备类型

装备槽数量(改前→改后)：4→4（加里波第为3→4）
装备种类 | 小型主炮 | 中型主炮 | 大型主炮 | 副炮 | 鱼雷 | 攻击机·战斗机·轰炸机 | 侦察机 | 雷达 | 炮弹 | 防空炮 | 反潜装备 | 发射器·导弹
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否可装备 | 是 | 是 | 是 | 是 | 否 | 否 | 是 | 是 | 是 | 是 | 否 | 是
备注 |  |  |  |  |  |  | 需有搭载量 | 不可装备声呐 |  |  |  |
不可装备的强化部件 | 铁锚、附加装甲(中型)、发烟筒

图鉴

改造

5 5
No. 1020
阿拉斯加
5 5
No. 1021
关岛

2 4
No. 1413
加里波第

## 航空母舰 ( 航母 ) / Standard Aircraft Carrier（CV）[编辑]

### 历史沿革[编辑]

航空母舰最初来源于驾驶飞机从舰船上起飞和着陆的设想。一战以来，各国都开始研究这种能搭载飞机的水面舰艇，但各国都以为这种舰船充其量只是舰队的补充，真正的海战还是要靠大舰巨炮。然而，经二战初期过几次运用航母的战役，各国发现航母拥有广阔的作战半径，能够先发制人，取得战斗的主动权，才大力发展这种舰船。航母在战争后期是海军实力的代表，其中“埃塞克斯饺子级”级航母在二战中一共建造了24艘之多，一举奠定了美国战后的世界霸主地位。直到今日，航空母舰已是现代海军不可或缺的武器也是海战最重要的舰艇之一。依靠航空母舰，一个国家可以在远离其国土的地方、在不依靠当地的机场的情况下施加军事压力和进行作战。时至今日，航空母舰已是现代海军不可或缺的利器，也成为了一个国家综合国力的象征。

### 游戏性能[编辑]

游戏中的航母主要以高索敌值探测对方配置，然后开幕先行攻击对方——装备战斗机能抢下制空权，让对方航母开幕乏力；而装备攻击机和轰炸机能在炮击战开始之前就狠狠地削弱对方的战斗力。即使是在炮击战，搭载大量轰炸机的航母也能造成不亚于BB炮击的伤害。虽然航母在经过多个节点的战斗后舰载机会逐渐损失从而影响攻击力，但航母们当之无愧是为队伍其他舰艇保驾护航，使她们能以最佳状态迎战BOSS的一把好手。

在舰队里编入大量航母可以让你在前三个节点享受秒杀的快感，对那些不需要攻打地图BOSS节点的捞船玩家来说，这是省下快速修理道具的最佳配置方式。

但由于2019年1月官方调整了游戏内的防空机制，主要是增加了舰船的舰种对于防空的影响，对小型舰增加了防空闪避，对大型舰增加了防空减伤，对中型舰两者都有少量提高，这一改变一定程度上削弱了航母的开幕威力，使得航母如果要达到和原来同样的开幕伤害需要用更好的飞机，但是命中问题则难以解决。所以航母在其后近2年的时间内都处于“面对低难度关卡时可以随便组队碾压；但面对高难度关卡时极度考验装备和船池积淀，难以发挥全部实力”的地位，普通玩家攻坚的主力仍然是大炮。

但是，随着列克星敦和萨拉托加的技能「航空战术先驱」的效果可以叠加、大黄蜂改造后的超强技能、勇猛的强力buff的加持，以及梯形阵加成可以影响航系的改动，航母队又找回了曾经的辉煌，现在又可以像从前一样快乐的洗地了。

需要注意的是，航母不能进行反潜，一般也无法参与夜战。且航母的攻击力受装备的影响较大，而且如何摆放这三种飞机，也是值得研究的学问。详参战斗机制。

战斗流程

阶段 | BUFF | 航空战 | 导弹战 | 先制反潜 | 先制鱼雷 | 炮击战·首轮炮击 | 炮击战·次轮炮击 | 鱼雷战 | 闭幕导弹 | 夜战
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否参与 | 是 | 是 | 否 | 否 | 否 | 是 | 否[1] | 否 | 否 | 否
备注 | 如果有的话 | 未大破才能参与 |  |  |  | 未中破才能参与 |  |  |  |

装备类型

装备槽数量(改前→改后)：4→4
装备种类 | 小型主炮 | 中型主炮 | 大型主炮 | 副炮 | 鱼雷 | 攻击机·战斗机·轰炸机 | 侦察机 | 雷达 | 炮弹 | 防空炮 | 反潜装备 | 发射器·导弹
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否可装备 | 否 | 否 | 否 | 是 | 否 | 是 | 是 | 是 | 否 | 是 | 否 | 否
备注 |  |  |  |  |  |  |  | 不可装备声呐 |  |  |  |
不可装备的强化部件 | 铁锚、附加装甲(中型)、发烟筒

1. ↑ 受到大凤·改技能「穿梭轰炸」加成后可参与次轮炮击（没有中破的情况下），但威力降低50%。此外，企业的技能「独木成林」可以使自身参与次轮炮击。

图鉴

3 3
No. 22
赤城
3 3
No. 23
加贺
3 3
No. 29
列克星敦(CV-2)
3 3
No. 30
萨拉托加
3 3
No. 31
大黄蜂
3 3
No. 118
齐柏林伯爵
4 4
No. 119
皇家方舟(91)
3 3
No. 120
约克城
4 4
No. 121
企业
3 3
No. 219
瑞鹤
3 3
No. 220
翔鹤
3 3
No. 221
飞龙
3 3
No. 222
苍龙
2 2
No. 225
黄蜂
3 4
No. 226
埃塞克斯
1 2
No. 232
贝亚恩
3 5
No. 325
列克星敦(CV-16)
3 4
No. 339
帝国
5 4
No. 374
汉考克
3 4
No. 426
彼得·施特拉塞尔
3 4
No. 433
提康德罗加
3 3
No. 469
本宁顿
2 2
No. 471
欧罗巴
2 2
No. 472
霞飞
2 2
No. 474
72工程
2 2
No. 494
G6
2 2
No. 498
复仇
4 4
No. 513
勇猛

改造

6 6
No. 1022
赤城
4 5
No. 1023
加贺
3 5
No. 1028
突击者
4 5
No. 1029
列克星敦(CV-2)
5 5
No. 1030
萨拉托加
6 5
No. 1031
大黄蜂
6 6
No. 1120
约克城
6 6
No. 1121
企业
4 5
No. 1219
瑞鹤
4 5
No. 1220
翔鹤
4 4
No. 1221
飞龙
4 4
No. 1222
苍龙
3 4
No. 1225
黄蜂
4 5
No. 1339
帝国

## 轻型航空母舰 ( 轻母 ) / Light Aircraft Carrier（CVL）[编辑]

### 历史沿革[编辑]

航空母舰的小型化版本，是海上航空力量的有力补充。正规空母的建造耗时长、成型慢，而且占用有限的大型船台，而这些建造或改装而来的轻型航母下水速度快。虽然在防护和载机量上都有不足的地方，但轻型航母在航母编队数量紧张时可以作为应急补充，跟随航母一同作战，在职责上与航母无异。

美国在二战时建造了大量由货船改造而来的“护航航母”，主要承担在低强度地区的护航、反潜、支援工作，在游戏里她们也一并归入“轻型航母”。需要注意的是，护航航母与轻型航母的职责有较大差异，护航航母一般不跟随大部队作战。

### 游戏性能[编辑]

游戏中的轻型航母除了航空母舰的一般攻击流程外，还可以参加先制反潜。和航母相比，轻型航母在火力、装甲、载机量、航速等方面存在缺陷，一般不参与主力部队的作战但其实全部装备上B25的轻母队威力也是不容小觑的，更多情况下是为驱逐舰编队提供护航，比如炸鱼，炸鱼，还有炸鱼；或者是在有舰种限制的情况下，作为能够同时兼顾制空与反潜的多面手来使用。另外，用航母队攻略有潜艇的地图时，可以编入轻型航母来负责反潜。

战斗流程

阶段 | BUFF | 航空战 | 导弹战 | 先制反潜 | 先制鱼雷 | 炮击战·首轮炮击 | 炮击战·次轮炮击 | 鱼雷战 | 闭幕导弹 | 夜战
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否参与 | 是 | 是 | 否 | 是 | 否 | 是 | 否[1] | 否 | 否 | 否
备注 | 如果有的话 | 未大破才能参与 |  | 需要单横阵且未中破 |  | 未中破才能参与；优先反潜 |  |  |  |

装备类型

装备槽数量：3
装备种类 | 小型主炮 | 中型主炮 | 大型主炮 | 副炮 | 鱼雷 | 攻击机·战斗机·轰炸机 | 侦察机 | 雷达 | 炮弹 | 防空炮 | 反潜装备 | 发射器·导弹
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否可装备 | 否 | 否 | 否 | 是 | 否 | 是 | 是 | 是 | 否 | 是 | 否 | 否
备注 |  |  |  |  |  | 不可装备天河 |  | 不可装备声呐 |  |  |  |
不可装备的强化部件 | 普列塞水下防护系统、附加装甲(大型)、发烟筒

1. ↑ 受到大凤·改技能「穿梭轰炸」加成后可参与次轮炮击（没有中破的情况下），但威力降低50%。

图鉴

2 3
No. 24
祥凤
2 3
No. 25
瑞凤
0 2
No. 26
百眼巨人
0 2
No. 27
兰利
2 3
No. 28
突击者
1 3
No. 122
龙骧
1 3
No. 123
博格
2 3
No. 124
追赶者
2 3
No. 125
巨像
2 3
No. 126
普林斯顿
1 2
No. 127
独角兽
2 3
No. 227
飞鹰
2 3
No. 228
隼鹰
1 2
No. 229
凤翔
1 2
No. 230
竞技神
2 2
No. 311
瓜达卡纳尔
2 3
No. 320
鹞鹰
1 2
No. 332
神鹰
1 2
No. 375
圣哈辛托
1 3
No. 419
桑提
2 2
No. 427
塞班
2 2
No. 470
甘比尔湾

改造

3 4
No. 1024
祥凤
3 4
No. 1025
瑞凤
1 2
No. 1026
百眼巨人
1 2
No. 1027
兰利
2 3
No. 1123
博格
3 4
No. 1124
追赶者
4 5
No. 1125
埃罗芒什
3 4
No. 1126
普林斯顿
3 4
No. 1227
飞鹰
3 3
No. 1228
隼鹰

## 装甲航母 ( 装母 ) / Armored Aircraft Carrier（AV）[编辑]

### 历史沿革[编辑]

装甲航母是“装甲飞行甲板航母”的简称，说明了航母的装甲敷设方式，与之相对应的是“核心舱防护航母”和“无防护航母”。装甲航母的概念最先来源于对航母作战能力的保护。常规布局的航母被炸弹命中后飞行甲板会损坏，短时间内无法起降飞机，相当于丧失了作战能力。而装甲航母的飞行甲板上铺设了装甲（厚度通常大于3英寸），可抵御一定当量的穿甲炸弹（通常为1000磅级），确保飞行甲板的完整性。装甲航母最先由英国人发明，美国、日本随后都有设计装甲航母，而到战后，几乎所有现代航母的飞行甲板都有铺设装甲。

### 游戏性能[编辑]

装母对对方开幕轰炸机的攻击有高达75%的额外减伤，连B25都奈何不了她们，再配合战列舰级别的装甲除了天鹰这个例外，生存性几乎不成问题。而且装母在中破时仍然可以参与炮击战。但目前游戏内的强力装母数量太少，而且大多数的载机量都不是太高，持久战表现乏力，目前比较强力的装母有日系的大凤和信浓、让鱼雷机打出轰炸机输出的不挠，对BB特攻的可畏，以及提供强力光环的胜利，剩下的则较为一般，其他时候装母可以作为航母的同位替代。

战斗流程

阶段 | BUFF | 航空战 | 导弹战 | 先制反潜 | 先制鱼雷 | 炮击战·首轮炮击 | 炮击战·次轮炮击 | 鱼雷战 | 闭幕导弹 | 夜战
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否参与 | 是 | 是 | 否 | 否 | 否 | 是 | 否[1] | 否 | 否 | 否
备注 | 如果有的话 | 未大破才能参与 |  |  |  | 未大破才能参与 |  |  |  |

装备类型

装备槽数量：4
装备种类 | 小型主炮 | 中型主炮 | 大型主炮 | 副炮 | 鱼雷 | 攻击机·战斗机·轰炸机 | 侦察机 | 雷达 | 炮弹 | 防空炮 | 反潜装备 | 发射器·导弹
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否可装备 | 否 | 否 | 否 | 是 | 否 | 是 | 是 | 是 | 否 | 是 | 否 | 否
备注 |  |  |  |  |  |  |  | 不可装备声呐 |  |  |  |
不可装备的强化部件 | 发烟筒

1. ↑ 受到大凤·改技能「穿梭轰炸」加成后可参与次轮炮击（没有中破的情况下），但威力降低50%。此外，皇家方舟(R09)的技能「新时代」可以使自身参与次轮炮击。

图鉴

3 3
No. 117
大凤
4 4
No. 223
信浓
3 3
No. 224
可畏
3 3
No. 319
不挠
2 3
No. 338
天鹰
3 3
No. 370
光辉
3 3
No. 404
怨仇
3 3
No. 455
皇家方舟(R09)
2 2
No. 483
胜利
0 2
No. 486
G15
2 3
No. 510
G14

改造

4 5
No. 1117
大凤
4 4
No. 1118
齐柏林伯爵
6 5
No. 1223
信浓
3 4
No. 1224
可畏
2 5
No. 1483
胜利

## 重巡洋舰 ( 重巡 ) / Heavy Cruiser（CA）[编辑]

### 历史沿革[编辑]

重巡洋舰是伦敦条约所规定的一种特殊的轻巡洋舰，具体溯源请参照“轻巡洋舰”一段。

根据1922年签订的《华盛顿海军条约》，各国停止了主力舰的建造，而条约限制以外的最强辅助舰，也就是标准排水量10000吨，主炮口径203毫米的巡洋舰成为各国争相建造的对象，这些军舰被称为“条约巡洋舰”。在此之后建造的条约型巡洋舰，在搭载8~10门主炮上如出一辙，但就其用途，其设计重点是偏重攻击、防御或者是航速，各国之间有很大的差异。

到1930年，伦敦海军条约规定了排水量不超过10000吨，主炮口径在155毫米以上，203毫米以下的舰船为A等巡洋舰，也就是俗称的“重巡洋舰”，许多原来的“轻巡洋舰”也在此时被重新分类为“重巡洋舰”。在此期间各国由于吨位限制也没有新造较多的重巡洋舰。

到40年代前条约所有条约失效后，只有美国新设计制造了大型的巡洋舰，这就是巴尔的摩级，也是美国的第一种摆脱条约限制的重巡洋舰，一直发展到后来的德梅因级。再往后，各国都不再发展重巡洋舰了。

游戏中除了第一次伦敦海军条约所指的A等巡洋舰外，历史上的装甲巡洋舰在游戏中皆被算作重巡。如：乔治·埃夫洛夫、埃德加·居内和留里克。

### 游戏性能[编辑]

游戏中的重巡相比于其他种类的舰船特点非常不明显，相对于BB输出太低，相对于DD消耗又太大，还不像CL能够反潜。因此，在早期版本里重巡几乎是实用性最低的舰种，能拿得出手的只有美如画的立绘，再加上CA的外表年龄几乎都是高中生，所以游戏里CA的唯一用途就只有当偶像了。玩家之间所说的“偶像”就是指重巡，初始四系的当家花旦分别是欧根亲王、昆西、青叶、肯特。

非要说实用性的话，一些改造后的重巡可以凭借多种多样的技能为舰队承担各种功能性任务。不要想太多，就是告诉你改造后的重巡才勉强能用。。

然而，随着巴尔的摩这里专指一技能“不朽的英魂”和德梅因级重巡的技能实装，特定组合的重巡编队在夜战可以发挥出显著的伤害，目前游戏内唯一可以作为高难度活动攻坚主力的重巡体系只有美系的“巴尔的摩美巡体系”，凭借巴尔的摩的核心技能以及美系重巡强力的属性，“巴尔的摩美巡体系”已经成为了活动攻坚的一种新思路。这个体系里六艘满级美巡的裸火力可以达到110左右，已经和BB差不多，而且还拥有BB队没有的优势：

- 美巡的高闪避和高索敌重巡有较高的索敌和闪避成长，因此生存主要靠中保和高闪避，所以重巡是等级要求较高的舰种，等级过低的重巡是完全无法使用的
- 无雷重巡的夜战高输出因为美巡基本都是没有鱼雷的，而游戏里无雷重巡的夜战系数加成要高于有雷重巡，所以高练度巴尔的摩体系美巡队的夜战输出是非常恐怖的，甚至要高于战列和战巡

但必须指出的是，重巡仍然无法撼动大炮们的地位，其主要原因是无法像战列战巡一样装备大口径主炮，导致她们即使装备超重弹日战最高输出还是不及战列战巡，所以重巡属于半后手舰种，需要靠存活到夜战来进行爆炸输出，但仅仅靠夜战豪赌并不能算作可靠的攻坚方法；其次，重巡在日战无法对高护甲敌人造成可观伤害，因为重巡无法装备穿甲弹，所以重巡队更多的是在敌人大多是路基单位（护甲极低）或者限制大型舰时才会考虑上场；最后，由于防空机制的改变，重巡作为中型舰在防空闪避和防空减伤均不占优势，所以极易被对方的航空开幕击中中破甚至大破，相比之下，拥有更高血量装甲以及防空减伤的战列战巡更容易生存。目前美巡队六艘美巡推荐威奇塔、巴尔的摩、萨勒姆、旧金山、彭萨科拉和波特兰。

战斗流程

阶段 | BUFF | 航空战 | 导弹战 | 先制反潜 | 先制鱼雷 | 炮击战·首轮炮击 | 炮击战·次轮炮击 | 鱼雷战 | 闭幕导弹 | 夜战
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否参与 | 是 | 否 | 否 | 否 | 否 | 是 | 是 | 是[1] | 否 | 是
备注 | 如果有的话 |  |  |  |  |  | 射程长或超长可参与次轮炮击 | 未大破才能参与 |  | 未大破才能参与

装备类型

装备槽数量(改前→改后)：3→4
装备种类 | 小型主炮 | 中型主炮 | 大型主炮 | 副炮 | 鱼雷 | 攻击机·战斗机·轰炸机 | 侦察机 | 雷达 | 炮弹 | 防空炮 | 反潜装备 | 发射器·导弹
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否可装备 | 是 | 是 | 否 | 是 | 是[1] | 否 | 是 | 是 | 否 | 是 | 否 | 否
备注 |  |  |  |  |  |  | 需有搭载量 | 不可装备声呐 | 不可装备91式 |  |  |
不可装备的强化部件 | 普列塞水下防护系统、附加装甲(大型)

1. ↑ 跳转至： 1.0 1.1 自身鱼雷值不为0才能装备鱼雷或参与鱼雷战，因此所有美国重巡洋舰、莫斯科和彼得罗巴甫洛夫斯克都不可装备鱼雷，也不参与鱼雷战。

图鉴

2 2
No. 32
高雄
2 2
No. 33
爱宕
2 2
No. 34
摩耶
2 2
No. 35
鸟海
2 2
No. 36
希佩尔海军上将
2 2
No. 37
布吕歇尔
2 2
No. 38
欧根亲王
2 2
No. 39
威奇塔
2 2
No. 40
昆西
2 2
No. 131
古鹰
2 2
No. 132
加古
2 2
No. 133
青叶
2 2
No. 134
衣笠
2 2
No. 135
伦敦
2 2
No. 136
肯特
2 2
No. 137
波特兰
2 2
No. 138
印第安纳波利斯
2 2
No. 139
彭萨科拉
2 2
No. 140
盐湖城
2 2
No. 141
北安普顿
2 2
No. 142
休斯顿
2 2
No. 143
新奥尔良
2 2
No. 233
最上
2 2
No. 234
三隈
2 2
No. 235
铃谷
2 2
No. 236
熊野
2 2
No. 237
萨福克
2 2
No. 238
约克
2 2
No. 239
埃克赛特
2 2
No. 240
旧金山
4 4
No. 241
巴尔的摩
3 3
No. 243
德梅因
2 2
No. 245
扎拉
2 2
No. 246
阿尔及利亚
1 2
No. 297
乔治·埃夫洛夫
1 2
No. 324
塔斯卡卢萨
2 2
No. 326
诺福克(78)
3 3
No. 328
妙高
2 2
No. 329
奥古斯塔
2 2
No. 340
波尔扎诺
3 3
No. 352
莫斯科
3 2
No. 357
羽黑
1 2
No. 364
加纳里亚斯
1 2
No. 376
埃德加·居内
2 2
No. 382
坎伯兰
3 3
No. 388
纽波特纽斯
2 2
No. 389
留里克
4 3
No. 410
萨勒姆
1 2
No. 412
堪培拉
0 2
No. 431
什罗普郡
1 2
No. 432
波士顿
0 2
No. 437
鞍马
0 2
No. 438
梅肯
2 2
No. 447
迪凯纳
0 3
No. 451
伊吹
2 2
No. 452
萨里
2 3
No. 456
彼得罗巴甫洛夫斯克
0 2
No. 487
五月二十五
2 2
No. 508
安萨尔多
2 2
No. 511
德文郡
2 2
No. 528
芝加哥

改造

3 3
No. 1032
高雄
3 3
No. 1033
爱宕
3 3
No. 1034
摩耶
3 3
No. 1035
鸟海
3 3
No. 1036
希佩尔海军上将
3 3
No. 1037
布吕歇尔
3 4
No. 1038
欧根亲王
3 4
No. 1039
威奇塔
2 3
No. 1040
昆西
3 2
No. 1131
古鹰
3 2
No. 1132
加古
3 2
No. 1133
青叶
3 3
No. 1135
伦敦
3 3
No. 1136
肯特
4 4
No. 1137
波特兰
4 4
No. 1139
彭萨科拉
3 3
No. 1141
北安普顿
3 3
No. 1142
休斯顿
3 3
No. 1143
新奥尔良
4 3
No. 1240
旧金山
4 4
No. 1241
巴尔的摩
1 3
No. 1431
什罗普郡

## 轻巡洋舰 ( 轻巡 ) / Light Cruiser（CL）[编辑]

### 历史沿革[编辑]

在1910年前后，为了在舰队前方海域进行搜索、侦察，或者担任高速机动化驱逐（雷击）部队的旗舰，要求具备高速、机动、远洋适应性好、耐波性能高等特点的舰船，于是便诞生了轻巡洋舰。英国的轻巡洋舰乃是现代巡洋舰的起点。之后，随着驱逐舰航速越来越快，对于轻巡洋舰具备高航速和适应性，能够满足与己方驱逐舰共同行动。并具有能够击毁敌方驱逐舰的强大火力之要求与日俱增。英、德、美、日等国纷纷开始巡洋舰的军备竞赛，追求压倒别国轻巡洋舰的更快航速，更大吨位，更强武备。日本的“古鹰”型轻巡洋舰以搭载200毫米口径主炮的惊人火力受到世界注目，直接导致了两次裁军条约的签订。

直到1930年伦敦条约签订后，轻巡洋舰被定义为排水量不超过10000吨，主炮口径不超过155毫米的巡洋舰（B等巡洋舰）。该条约成立后各国海军的造舰对象转到了大型的轻巡洋舰。如日本的“最上”级、美国的“布鲁克林”级、英国的“南安普顿”级都是在条约限制下尽可能地压榨巡洋舰的性能。到40年代前，所有裁军条约失效，在此期间设计的轻巡洋舰由各国的发展脉络不同而担任防空、雷击、屏护等不同职能。

游戏中此分类的舰船一般都是第一次伦敦海军条约所指的B等巡洋舰。其中“基洛夫”级在英苏之间的条约中并没有明确分类，但苏联对她的分类是轻巡洋舰。“CNT巡洋舰”是装甲巡洋舰，按照游戏此前对历史上装甲巡洋舰的分类都是属于重巡洋舰，但该舰可能还考虑了船只吨位而划分到轻巡洋舰。

### 游戏性能[编辑]

游戏中的轻巡一般担任辅助和反潜任务并没有什么卵用的舰种。海伦娜以她极高的火力和及其实用的技能成为众多玩家的主力之一，而改造后的塔林也凭借优异的属性跻身一线。

在重巡还没有靠巴尔的摩带起来时，轻巡因其可以装备长射程炮进行两轮炮击反潜而拥有较高的实用性，但现在重巡攻坚变得可行，驱逐又可以靠技能和装备同样进行两轮炮击，并且驱逐的闪避雷击还高于轻巡，身为小型舰的驱逐在防空属性上也比身为中型舰的轻巡有优势，而轻巡则成了地位比较尴尬的舰种，一般只作为混编队里上buff的工具人出现。

战斗流程

阶段 | BUFF | 航空战 | 导弹战 | 先制反潜 | 先制鱼雷 | 炮击战·首轮炮击 | 炮击战·次轮炮击 | 鱼雷战 | 闭幕导弹 | 夜战
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否参与 | 是 | 否 | 否 | 是 | 否 | 是 | 是 | 是[1] | 否 | 是
备注 | 如果有的话 |  |  | 需要单横阵 |  |  | 射程长或超长可参与次轮炮击 | 未大破才能参与 |  | 未大破才能参与

装备类型

装备槽数量(改前→改后)：3→3（夕张、塔林为3→4）
装备种类 | 小型主炮 | 中型主炮 | 大型主炮 | 副炮 | 鱼雷 | 攻击机·战斗机·轰炸机 | 侦察机 | 雷达 | 炮弹 | 防空炮 | 反潜装备 | 发射器·导弹
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否可装备 | 是 | 是 | 否 | 是 | 是[1] | 否 | 是 | 是 | 是 | 是 | 是 | 否
备注 |  | 仅限轻型主炮 |  |  |  |  | 需有搭载量 |  | 不可装备91式、超重弹 |  |  |
不可装备的强化部件 | 铁锚、普列塞水下防护系统、附加装甲(大型)、附加装甲(中型)

1. ↑ 跳转至： 1.0 1.1 自身鱼雷值不为0才能装备鱼雷或参与鱼雷战（朱诺改有鱼雷值但不能装备鱼雷，可参与鱼雷战），因此美国轻巡洋舰（除奥马哈、底特律、朱诺(CL-52)改以外）、大淀、虎、德·鲁伊特、塔林、德里、科伦坡、大淀(苍青幻影)、仁淀不可装备鱼雷，也不参与鱼雷战。

图鉴

1 2
No. 41
天龙
1 2
No. 42
龙田
1 2
No. 43
北上
1 2
No. 44
大井
1 2
No. 45
五十铃
1 2
No. 46
夕张
1 2
No. 47
柯尼斯堡
1 2
No. 48
卡尔斯鲁厄
1 2
No. 49
科隆
1 2
No. 50
天狼星
1 2
No. 51
林仙
1 2
No. 52
加拉蒂亚
1 2
No. 53
佩内洛珀
1 2
No. 54
曙光女神
1 2
No. 55
奥马哈
1 2
No. 56
亚特兰大
1 2
No. 57
朱诺(CL-52)
1 2
No. 58
布鲁克林
2 2
No. 59
海伦娜
1 2
No. 60
宁海
1 2
No. 61
平海
1 2
No. 144
基洛夫
1 2
No. 145
川内
1 2
No. 146
神通
1 2
No. 147
那珂
1 2
No. 148
M计划
1 2
No. 149
埃姆登
1 2
No. 150
翡翠
1 2
No. 151
进取
1 2
No. 152
爱丁堡
1 2
No. 153
贝尔法斯特
1 2
No. 157
圣地亚哥
1 2
No. 158
圣胡安
1 2
No. 160
摩尔曼斯克
1 2
No. 161
德·鲁伊特
0 2
No. 162
逸仙
1 2
No. 247
香取
1 2
No. 248
大淀
1 2
No. 249
莱比锡
2 2
No. 250
伍斯特
2 2
No. 251
奥克兰
2 2
No. 252
克利夫兰
0 2
No. 253
应瑞
0 2
No. 254
肇和
1 2
No. 302
圣路易斯
1 2
No. 304
圣女贞德
1 2
No. 312
纽伦堡
1 2
No. 313
阿贾克斯
1 2
No. 314
哥特雄狮
1 2
No. 333
德格拉斯
1 2
No. 337
伟大的庞贝
1 2
No. 341
龙骑兵
1 2
No. 346
谢菲尔德
1 2
No. 347
蒙彼利埃
1 2
No. 348
丹佛
2 2
No. 353
斯维尔德洛夫
1 2
No. 354
阿尔贝托·迪·朱桑诺
1 2
No. 356
爱丽
1 2
No. 360
虎
2 2
No. 365
门德斯·努涅斯
1 2
No. 371
海王星
1 2
No. 379
哥伦比亚
1 2
No. 383
奥斯塔公爵
0 2
No. 387
海圻
1 2
No. 390
库图佐夫
1 2
No. 398
德里
2 2
No. 399
阿布鲁奇公爵
2 2
No. 400
七省联盟
2 2
No. 405
乔治莱格
1 2
No. 411
黛朵
2 2
No. 413
加里波第
1 2
No. 420
亚尔古水手
2 2
No. 421
萨凡纳
2 2
No. 422
凤凰城
1 2
No. 430
捷尔任斯基
1 2
No. 434
亨廷顿
1 2
No. 443
阿贺野
1 2
No. 444
红色高加索
2 2
No. 459
底特律
1 3
No. 462
多摩
2 2
No. 465
爪哇
2 2
No. 473
阿非利加征服者西庇阿
1 2
No. 481
仁淀
1 3
No. 482
大淀(苍青幻影)
2 2
No. 491
夏伯阳
2 2
No. 492
壮丽
2 2
No. 495
光荣(轻巡洋舰)
2 2
No. 504
费城
2 2
No. 512
科伦坡
2 2
No. 515
伏罗希洛夫
2 2
No. 516
日丹诺夫
1 2
No. 526
朱诺(CL-119)
0 2
No. 527
CNT巡洋舰

改造

1 2
No. 1041
天龙
1 2
No. 1042
龙田
2 3
No. 1045
五十铃
2 3
No. 1046
夕张
2 2
No. 1047
柯尼斯堡
2 2
No. 1048
卡尔斯鲁厄
2 2
No. 1049
科隆
3 3
No. 1050
天狼星
2 3
No. 1054
重庆
1 2
No. 1055
奥马哈
2 2
No. 1056
亚特兰大
3 3
No. 1057
朱诺(CL-52)
2 2
No. 1058
奥希金斯
3 4
No. 1059
海伦娜
1 2
No. 1060
宁海
1 2
No. 1061
平海
2 2
No. 1145
川内
2 2
No. 1150
翡翠
2 2
No. 1151
进取
2 2
No. 1160
摩尔曼斯克
1 2
No. 1162
逸仙
2 2
No. 1247
香取
2 2
No. 1249
莱比锡
2 2
No. 1456
塔林

## 重雷装巡洋舰 ( 雷巡 ) / Torpedo Cruiser（CLT）[编辑]

### 历史沿革[编辑]

说到日本的重雷装巡洋舰，不得不从日军的鱼雷战术说起。由于华盛顿条约的签订，日本海军的主力舰队对美国海军处于劣势。为了扭转这种局面，日军提出了逐次削弱美军舰队各种辅助兵力的“渐减迎击”策略，使其舰队实力下降到与己方相当，再进行舰队决战。而超远距离的雷击战术，正是这种策略的重要一环。

按照日军的战术，两军互相发现后，装备了氧气鱼雷的重巡洋舰与重雷装舰将在双方主力舰炮战的极限射程之外，进行大量（200-300枚）鱼雷齐射。93式氧气鱼雷的超远射程为这种战术提供了可行性，而它隐蔽性高、威力大的特点则十分适合袭击的突然性。这些鱼雷将在30分钟左右与目标接触，在此期间，主力舰编队（昼战战术）或各巡洋舰战队（夜战战术）与敌方主力拉近距离。在与敌方主力展开交战的同时或之后不久，鱼雷群刚好与敌方接触，就算因为命中率低不能重创敌军，也会极大地扰乱敌方阵形。此时，后续编队乘机进行突击，将敌方一举击溃。

重雷装舰就是为了上述战术专门开发的功能性战舰，它单舷20具的鱼雷发射管能够对鱼雷齐射数量进行很好的补充，以此为代价的是孱弱的对海、对空，甚至反潜火力。虽然它与重巡洋舰都是这种战术的执行者，但除了远距离鱼雷齐射以外，重雷装舰没有更多的战术用途。

然而，二战中昼战的主角并不是大舰巨炮，而是航空母舰，白天的“渐减”攻击可以说是毫无用武之地。而夜战方面，在开战初期，日军的确完成了数次精彩的鱼雷攻击，但随着美军雷达的发展以及夜战训练，日军夜战的优势也渐渐消失殆尽。到二战末期，双方水面舰艇极少直接冲突，更多的是登陆战和空战，日军的两艘重雷装舰也被转为运输舰，黯然退场。

### 游戏性能[编辑]

如介绍所说，雷巡的火力、对空、对潜都十分低下，生存能力奇差，唯一的亮点是极高的雷装（同时弹药消耗也比一般轻巡要高得多）。

目前游戏内实装的三艘雷巡均需要觉醒技能才可以进行开幕雷击。雷巡均不能进行开幕反潜，只能进行昼战和夜战的反潜。虽然也能装备深弹投射器以及声呐，但说实话没人会蠢到用雷巡来反潜，因为首先雷巡自身的反潜值就极低（其中的“北上·改”和“大井·改”对潜都很低，固定为2），其次雷巡不能进行开幕反潜，虽然也可以带上声呐和深弹投射器，但此时你得到的就是一个雷击不行、对空残废、反潜半残的“反潜船”，能有什么用呢？专门负责反潜的舰种每一个都能吊打雷巡，所以雷巡直接带满鱼雷就行了。

目前雷巡的定位只相当于消耗量惊人的水上潜艇，用途较窄。

战斗流程

阶段 | BUFF | 航空战 | 导弹战 | 先制反潜 | 先制鱼雷 | 炮击战·首轮炮击 | 炮击战·次轮炮击 | 鱼雷战 | 闭幕导弹 | 夜战
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否参与 | 是 | 否 | 否 | 否 | 是 | 是 | 是 | 是 | 否 | 是
备注 | 如果有的话 |  |  |  | 满足技能生效条件且未大破 |  | 射程长或超长可参与次轮炮击 | 未大破才能参与 |  | 未大破才能参与

装备类型

装备槽数量(改前→改后)：3→3
装备种类 | 小型主炮 | 中型主炮 | 大型主炮 | 副炮 | 鱼雷 | 攻击机·战斗机·轰炸机 | 侦察机 | 雷达 | 炮弹 | 防空炮 | 反潜装备 | 发射器·导弹
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否可装备 | 是 | 是 | 否 | 是 | 是 | 否 | 否 | 是 | 是 | 是 | 是 | 否
备注 |  | 仅限轻型主炮 |  |  |  |  |  |  | 不可装备91式、超重弹 |  |  |
不可装备的强化部件 | 铁锚、普列塞水下防护系统、附加装甲(大型)、附加装甲(中型)

图鉴

1 2
No. 377
木曾

改造

3 3
No. 1043
北上
3 3
No. 1044
大井

## 航空巡洋舰 ( 航巡 ) / Cruiser, aviation（CAV）[编辑]

### 历史沿革[编辑]

所谓“航空巡洋舰”，就是将航母和巡洋舰结合在一起，或者说，带有飞行甲板，可以起降飞机，并装备有主炮的巡洋舰。这一概念最早在1927年由瑞典人提出，他们建造了世界上第一艘“航空巡洋舰”——哥特兰。此后，美国、日本都有过对航空巡洋舰的相关研究。

瑞典的“水上机巡洋舰”是受到当时盛行的“空中制胜论”影响，但当时瑞典无力承建航母，只能将飞行甲板搬到了相对“经济”的巡洋舰体上，同时保留一部分巡洋舰的职能，建造出了集空中力量、巡洋破交与水雷布置于一体的“哥特兰”号。但随着航空器的发展，瑞典发现用岸基飞机就足以完成防务工作，航母平台显得多余，在40年代就将哥特兰的飞行甲板撤去了。

美国的“飞行甲板巡洋舰”概念最先是为了充分利用条约所剩的航母吨位，并在30年代提出了代号为“CF-1”和“CF-2”的两个计划。但海军部经过论证后认为，这两种元素的结合纯属鸡肋，既难以胜任巡洋舰的职能，也难以胜任航母的职能，而且在战场上的定位模糊。“平甲板巡洋舰”也没有进一步发展。

日本的“航空巡洋舰”源于对“最上”号的改造计划和W-105舰“大淀”号原案之一。在二战后期，没有更多可用航母的日本海军希望在巡洋舰上搭载大量侦察机，以此能为友方舰只提供侦察、搜索、航空校射等辅助工作。虽然对最上的改造工作较为成功，但实际效果却没有想象中的优秀。

到现代，俄国的“基辅”级和“库兹涅佐夫级”重型载机巡洋舰似乎也可以看作是一种“航空巡洋舰”，但除了名字以外，恐怕没有人会将她们与二战时候的“航空巡洋舰”拉上关系吧，这是后话了。

### 游戏性能[编辑]

目前只有“哥特兰”、“最上·改”和“大淀•改”3艘航巡。在实装初期，航巡尽管能够装备水上飞机，但不具备反潜能力。4.2.0版本后，终于可以进行开幕反潜和炮击战阶段反潜。因为航巡舰种的特殊性，这使其拥有了更广泛的适用性，在活动上有着更灵活的用法。

战斗流程

阶段 | BUFF | 航空战 | 导弹战 | 先制反潜 | 先制鱼雷 | 炮击战·首轮炮击 | 炮击战·次轮炮击 | 鱼雷战 | 闭幕导弹 | 夜战
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否参与 | 是 | 是 | 否 | 否→是[1] | 否 | 是 | 是 | 是 | 否 | 是
备注 | 如果有的话 | 未大破才能参与 |  | 需要单横阵 |  |  | 射程长或超长可参与次轮炮击 | 未大破才能参与 |  | 未大破才能参与

装备类型

装备槽数量(改前→改后)：3→4
装备种类 | 小型主炮 | 中型主炮 | 大型主炮 | 副炮 | 鱼雷 | 攻击机·战斗机·轰炸机 | 侦察机 | 雷达 | 炮弹 | 防空炮 | 反潜装备 | 发射器·导弹
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否可装备 | 是 | 是 | 否 | 是 | 是 | 是 | 是 | 是 | 是 | 是 | 是 | 否
备注 |  |  |  |  |  | 仅可装备瑞云、晴岚、HE-119、萨博S.17BS、SR.A/1水上战斗机、瑞云12型、黄蜂直升机（AS.12）、H-34直升机（武装）、彗星（誉）、H-34G反潜直升机 |  |  | 不可装备91式 |  |  |
不可装备的强化部件 | 普列塞水下防护系统、附加装甲(大型)

1. ↑ 自2019.1.8的4.2.0版本后，航巡可以进行开幕反潜

图鉴

1 2
No. 308
哥特兰

改造

3 4
No. 1233
最上

2 4
No. 1248
大淀

## 浅水重炮舰 ( 重炮 ) / Monitor（BM）[编辑]

### 历史沿革[编辑]

浅水重炮舰最早出现于美国南北战争期间，其英文名“Monitor”即为世界上最早的浅水重炮舰——美国海军莫尼特号（USS Monitor）。皇家海军浅水重炮舰的概念最初来源于费舍尔勋爵的“波罗的海强袭计划”，在造价低廉的低干舷铁甲舰上直接安装大口径火炮用作近海炮击支援。例如皇家海军阿贝克隆比号就是将2.2万吨的勇敢级战列巡洋舰15英寸舰炮安装在7000吨的舰体上而成。浅水重炮舰亦为和驱逐舰、巡洋舰、潜艇等几种存活到战后现代的舰种。现代俄罗斯仍能看到他们的身影，例如俄罗斯边防军边境巡逻舰项目1208/81就是浅水重炮舰。

海防战舰（区别于日语的“海防舰”）的概念最早出现在斯堪的纳维亚半岛的国家中。与浅水重炮舰不同，海防战舰主炮口径更小，但航速更快，装甲更厚，是介于浅水重炮舰和巡洋舰之间的舰种。海防战舰的作用主要是拒止敌方的登陆舰队，而不是对陆支援。这些浅吃水的战舰可以在波罗的海的破碎水域自由航行，不受深水航线的限制，从而可以避开敌方编队的主力舰，猎杀来犯的巡洋舰。这些舰艇一直作为斯堪的纳维亚半岛的重要海防力量服役到60年代。

游戏里的“重炮”分类除了传统的浅水重炮舰外也包含了海防战舰。

### 游戏性能[编辑]

在游戏中，重炮拥有长射程、轻巡的血量护甲、比驱逐舰略高的弹药消耗、比重巡高一些的攻击力，以及目前全舰种中最低的闪避和航速。和大炮一样两轮炮击，一般用作小学生保姆，或者是少数活动地图负责带路。

一般仅在活动只允许使用小型舰，又需要强力的昼战输出时才会考虑重炮，但导驱和一批炮驱的出现又进一步挤压了重炮的出场率。

战斗流程

阶段 | BUFF | 航空战 | 导弹战 | 先制反潜 | 先制鱼雷 | 炮击战·首轮炮击 | 炮击战·次轮炮击 | 鱼雷战 | 闭幕导弹 | 夜战
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否参与 | 是 | 否 | 否 | 否 | 否 | 是 | 是 | 否 | 否 | 是
备注 | 如果有的话 |  |  |  |  |  | 射程长或超长可参与次轮炮击 |  |  | 未大破才能参与

装备类型

装备槽数量(改前→改后)：2→3
装备种类 | 小型主炮 | 中型主炮 | 大型主炮 | 副炮 | 鱼雷 | 攻击机·战斗机·轰炸机 | 侦察机 | 雷达 | 炮弹 | 防空炮 | 反潜装备 | 发射器·导弹
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否可装备 | 是 | 是 | 是 | 否 | 否 | 否 | 否 | 是 | 是 | 是 | 否 | 否
备注 |  |  |  |  |  |  |  | 不可装备声呐 |  |  |  |
不可装备的强化部件 | 普列塞水下防护系统、附加装甲(大型)

图鉴

1 2
No. 62
罗伯茨
1 2
No. 63
阿贝克隆比
1 2
No. 163
维那莫依嫩
1 2
No. 218
古斯塔夫五世
1 2
No. 259
吞武里
0 2
No. 309
诺夫哥罗德
1 2
No. 369
克莱夫勋爵
1 2
No. 384
法迪布鲁诺
2 2
No. 507
艾斯沃尔德

改造

1 2
No. 1062
罗伯茨
1 2
No. 1063
阿贝克隆比

## 驱逐舰 ( 驱逐 ) / Destroyer（DD）[编辑]

### 历史沿革[编辑]

驱逐舰起源于19世纪末，最初是为了反制敌方的鱼雷艇而产生的。随着时间的推移和技术的发展，驱逐舰逐渐替代了原来的反制目标，转而成为以鱼雷为主要攻击手段的舰艇。步入20世纪20年代，各国对驱逐舰都进行了研究，根据战场上的需求，各自发展出了重视炮击、重视鱼雷、重视防空等侧重点不一的驱逐舰。40年代，随着高平两用火炮及火控系统的发展，美国人首先提出了各方面均衡发展的“泛用型”的驱逐舰，这就是后来的“弗莱彻”级。事实证明“泛用型”的思想是成功的，直到战后，驱逐舰这种武器平台也向着多功能化发展。虽然当今的驱逐舰已经和二战时的概念相去甚远，但不得不承认经过数十年的发展，驱逐舰在海军中正在扮演越来越重要的角色。

需要注意的是，“紫石英”、“燕八哥”是护卫舰（sloop），“吕贝克”、“SKR-6”是护卫舰（frigate），“英格兰”和“塞缪尔•罗伯茨”是护航驱逐舰（destroyer escort），“伏尔铿”、“雉”、“T-23”、“T.995”和“墨尔波墨涅”是鱼雷艇（torpedo boat），但游戏中仍然归为驱逐舰一类。

### 游戏性能[编辑]

游戏中 驱逐舰 ( 小学生 ) 的火力、对空和装甲均不尽人意美系DD的对空除外，换取的是极高的闪避和鱼雷值。驱逐舰凭借闪避值活过炮击战，然后在鱼雷战和夜战用鱼雷给予敌方重创是最常见的用法。极少数因为技能的原因，在白天就能造成可观的输出，这一小部分驱逐舰也被戏称为“炮驱”。

驱逐舰是游戏里实装数量最多的舰种，改造数量也是最多的，技能类型多种多样，从体系领袖技能到单体生存技能再到高输出技能应有尽有，可以单体与其他舰种混编也可进行群体作战，具有多元化的作战体系和用途。驱逐编队从理论上可以攻克游戏里的所有敌方无导弹和无陆基单位的关卡，而且驱逐舰极低的出击和维修消耗也使得不少快速修理道具充裕的玩家用驱逐编队捞船。

一般来说，驱逐编队中应每人至少携带一个防空炮，提高开幕阶段的存活率。此外，携带鱼雷可以保证输出，携带深弹投射器和声呐可以提高反潜能力，携带动力系统则保证生存性。

战斗流程

阶段 | BUFF | 航空战 | 导弹战 | 先制反潜 | 先制鱼雷 | 炮击战·首轮炮击 | 炮击战·次轮炮击 | 鱼雷战 | 闭幕导弹 | 夜战
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否参与 | 是 | 否 | 否 | 是 | 是[1] | 是 | 是[2] | 是 | 否 | 是
备注 | 如果有的话 |  |  | 需要单横阵 |  |  | 射程长可参与次轮炮击 | 未大破才能参与 |  | 未大破才能参与

装备类型

装备槽数量(改前→改后)：2→3
装备种类 | 小型主炮 | 中型主炮 | 大型主炮 | 副炮 | 鱼雷 | 攻击机·战斗机·轰炸机 | 侦察机 | 雷达 | 炮弹 | 防空炮 | 反潜装备 | 发射器·导弹
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否可装备 | 是 | 否[2] | 否[2] | 否 | 是 | 否 | 否 | 是 | 是 | 是 | 是 | 否
备注 |  |  |  |  |  |  |  |  | 不可装备91式、超重弹 |  |  |
不可装备的强化部件 | 铁锚、普列塞水下防护系统、附加装甲(大型)、附加装甲(中型)

1. ↑ 阳炎和黑潮因为改造后技能“甲型驱逐舰”和“雷击特快”的效果而有概率参与先制鱼雷。
2. ↑ 跳转至： 2.0 2.1 2.2 塞缪尔•罗伯茨的技能“投石器”和吹雪的技能“孤注一掷”使其可以参与次轮炮击。装备了神秘武器的任意驱逐舰均可参与次轮炮击。

图鉴

1 2
No. 64
吹雪
1 2
No. 65
白雪
1 2
No. 66
初雪
1 2
No. 67
深雪
1 2
No. 68
晓
1 2
No. 69
响
1 2
No. 70
雷
1 2
No. 71
电
1 2
No. 72
绫波
1 2
No. 73
敷波
1 2
No. 74
Z1
1 2
No. 75
Z16
1 2
No. 76
Z21
1 2
No. 77
Z22
1 2
No. 78
Z24
1 2
No. 79
Z28
1 2
No. 80
Z31
1 2
No. 81
紫石英
1 2
No. 82
萤火虫
1 2
No. 83
标枪
1 2
No. 84
天后
1 2
No. 85
黑背豺
1 2
No. 86
哥萨克人
1 2
No. 87
爱斯基摩人
1 2
No. 88
旁遮普人
1 2
No. 89
弗莱彻
1 2
No. 90
卡辛杨
1 2
No. 91
安东尼
1 2
No. 92
布雷恩
1 2
No. 93
基林
1 2
No. 94
基阿特
1 2
No. 95
弗兰克·诺克斯
1 2
No. 96
鲍尔
1 2
No. 97
果敢
1 2
No. 98
沃克兰
2 3
No. 99
空想
1 2
No. 164
秋月
1 2
No. 165
凉月
1 2
No. 166
阳炎
1 2
No. 167
不知火
1 2
No. 168
黑潮
2 2
No. 169
雪风
1 2
No. 170
Z3
1 2
No. 171
Z46
1 2
No. 172
热心
1 2
No. 173
阿卡司塔
1 2
No. 174
索玛雷兹
1 2
No. 175
维纳斯
1 2
No. 176
军团
1 2
No. 177
撒切尔
1 2
No. 178
沙利文
1 2
No. 179
西格斯比
1 2
No. 180
奥班农
1 2
No. 181
威廉·D·波特
1 2
No. 182
波特
1 2
No. 183
拉菲(DD-724)
1 2
No. 184
拉菲(DD-459)
1 2
No. 185
卡米契亚·内拉
1 2
No. 186
阿维埃尔
1 2
No. 187
安东尼奥·达诺利
1 2
No. 188
乌戈里尼·维瓦尔迪
1 2
No. 192
塔什干
1 2
No. 193
恩格斯
1 2
No. 260
睦月
1 2
No. 261
白露
1 2
No. 262
时雨
1 2
No. 263
村雨
1 2
No. 264
夕立
1 2
No. 265
岚
2 2
No. 267
岛风
1 2
No. 268
峰风
1 2
No. 269
Z17
1 2
No. 270
Z18
1 2
No. 271
吸血鬼
1 2
No. 272
海达人
1 2
No. 275
康弗斯
1 2
No. 276
戴森
1 2
No. 277
克拉克斯顿
1 2
No. 278
霍埃尔
1 2
No. 279
塞缪尔·罗伯茨
1 2
No. 280
约翰斯顿
2 2
No. 281
雷鸣
1 2
No. 301
马汉
1 2
No. 306
巴夫勒尔
1 2
No. 310
库欣
1 2
No. 315
宵月
1 2
No. 316
明斯克
1 2
No. 322
希尔曼
1 2
No. 323
基辅
1 2
No. 327
斯特雷特
1 2
No. 330
卫士
1 2
No. 334
不惧
1 2
No. 335
伏尔塔
1 2
No. 336
竹
1 2
No. 342
江原
1 2
No. 344
忠武
1 2
No. 349
初月
1 2
No. 350
菲尔普斯
1 2
No. 358
天津风
1 2
No. 372
早春
1 2
No. 378
斯普利特
1 2
No. 385
S113
1 2
No. 392
天雾
1 2
No. 393
查尔斯·奥斯本
1 2
No. 394
泰勒
1 2
No. 395
闪电
1 2
No. 406
哈曼
1 2
No. 414
凯利
1 2
No. 415
英格兰
2 2
No. 416
47工程
1 2
No. 417
可怖
1 2
No. 423
燕八哥
1 2
No. 424
蒂默曼
1 2
No. 425
史密斯
1 2
No. 428
尼古拉斯
1 2
No. 429
马伊·布雷泽
1 2
No. 439
冬月
1 2
No. 440
阿尔维塞·达·摩斯托
1 2
No. 445
哈尔福德
1 2
No. 449
莫加多尔
2 2
No. 453
野分
1 2
No. 457
潮
2 2
No. 476
科顿艾尔
1 2
No. 477
马戈迪尼
2 2
No. 479
桑普森
1 2
No. 485
英格拉姆
0 2
No. 489
历战
2 2
No. 496
诺福克(DL-1)
1 2
No. 500
伏尔铿
1 2
No. 501
拉弗雷
2 2
No. 503
T-23
1 2
No. 505
雉
2 2
No. 509
谦逊
2 2
No. 517
吕贝克
2 2
No. 519
T.995
2 2
No. 531
墨尔波墨涅

改造

3 5
No. 1064
吹雪
2 2
No. 1065
白雪
3 3
No. 1066
初雪
3 4
No. 1067
深雪
2 2
No. 1068
晓
3 3
No. 1069
信赖
2 2
No. 1070
雷
3 3
No. 1071
电
5 5
No. 1072
绫波
2 3
No. 1073
敷波
2 2
No. 1074
Z1
2 3
No. 1075
Z16
3 3
No. 1076
Z21
2 3
No. 1077
Z22
2 2
No. 1080
Z31
3 5
No. 1081
紫石英
3 3
No. 1082
萤火虫
2 2
No. 1083
标枪
2 2
No. 1084
天后
2 2
No. 1085
黑背豺
2 2
No. 1086
哥萨克人
2 2
No. 1087
爱斯基摩人
2 3
No. 1088
旁遮普人
3 4
No. 1089
弗莱彻
2 2
No. 1092
布雷恩
2 3
No. 1093
基林
2 3
No. 1098
沃克兰
3 4
No. 1099
空想
2 2
No. 1164
秋月
2 2
No. 1165
凉月
2 4
No. 1166
阳炎
2 2
No. 1167
不知火
2 3
No. 1168
黑潮
4 5
No. 1169
丹阳
2 3
No. 1171
Z46
2 2
No. 1175
维纳斯
3 3
No. 1178
沙利文
2 5
No. 1181
威廉·D·波特
2 2
No. 1182
波特
3 4
No. 1183
拉菲(DD-724)
2 2
No. 1185
机灵
3 3
No. 1187
安东尼奥·达诺利
5 5
No. 1188
乌戈里尼·维瓦尔迪
3 3
No. 1192
塔什干
2 3
No. 1265
岚
4 6
No. 1269
Z17
2 2
No. 1270
Z18
2 3
No. 1278
霍埃尔
3 4
No. 1279
塞缪尔·罗伯茨
3 3
No. 1280
约翰斯顿
2 3
No. 1301
马汉
2 2
No. 1306
巴夫勒尔
2 2
No. 1316
明斯克
2 2
No. 1323
基辅
3 4
No. 1335
伏尔塔
2 3
No. 1342
江原
2 3
No. 1344
忠武
5 5
No. 1372
早春
2 3
No. 1496
诺福克(DL-1)

## 导弹驱逐舰 ( 导驱 ) / Destroyer, anti-ship guided missile（ASDG）[编辑]

### 历史沿革[编辑]

随着电子技术的发展，精确制导武器自二战末期开始登上战争舞台，而制导武器添加动力系统之后便成为导弹。导弹武器相对火炮有很多优势，导弹的命中率远高于火炮，而且导弹武器不需要复杂的反后座机构，所以威力巨大的导弹可以像鱼雷一样装备到小型军舰上。按照用途来分，可以简单分为舰舰导弹，舰空导弹，反潜导弹。视搭载军舰用途的不同，这些导弹在军舰上有不同的搭载组合，军舰同时也可以简单划分为通用，防空，反潜等军舰。而装备了导弹的驱逐舰，也顺理成章地泛称为“导弹驱逐舰”。与此同时，传统的军舰分类方法被抛弃，美国和苏联则各自发展了一套自己的分类体系。

冷战初期，海军处于绝对劣势的苏联迫切需要一种以弱克强的非对称手段，除了航空兵和传统鱼雷以外，新兴的导弹武器被视作克制强敌的契机。50年代，第一代成熟的反舰导弹被搬上了苏联海军的各种军舰。出于防空的需要，苏联也研制了一系列舰空导弹，但是除了少数型号外，总体水平不如西方。苏联独特的反潜导弹具备反舰反潜双重用途，在面对不同的目标的时候使用不同的战斗部。

在二战末期的防空作战中，美军开始研制用于防空的制导武器，发展到冷战初期便是著名的3T计划，最终的三款防空导弹（黄铜骑士，小猎犬，鞑靼人）涵盖了远中近各个区域，在舰队防空中各司其职。在苏联的导弹威胁出现后，防空网的重要性更加凸显，除了传统的航空攻击，她们还需要提防和拦截蜂拥而至的反舰导弹。由于西方依然保有大量火炮军舰，尤其美国海军以航母为攻防核心，而且防空导弹也具备一定的对海能力，所以并不太重视反舰导弹，一直到70,80年代才普及反舰导弹。

中国海军的导弹武器起步来自于苏联援助的两款导弹，其中，反舰导弹(即著名的P-15，SS-N-2冥河)使用主动雷达制导，中国在该弹的基础上仿制出了上游-1反舰导弹，并首先装备了四大金刚驱逐舰(鞍山，抚顺，长春，太原)，053和01型护卫舰也装备了该弹。在仿制544岸舰导弹时并不顺利，所以中国的岸舰导弹实际上是由舰舰导弹系列发展而来。

在导弹发展史中，不得不提到1967年的“埃拉特号事件”——埃及海军两艘75吨的导弹艇以零代价用4枚“冥河”导弹击毁了以色列海军一艘1700吨的驱逐舰。这一结果令各国海军为之惊愕，之前从未有战舰在这种吨位劣势上取得如此大的战果。如此类推，“巨舰大炮无用论”的观点开始占据了主流，世界各国纷纷抛弃了除航母以外传统的巨舰，转而发展小型导弹军舰。

但话说回来，巨舰大炮真的在小小的导弹面前毫无优势吗？在冷战格局下，传统的大型炮舰与新兴的导弹艇之间的对决居然从未发生过，各国也无从实证五花八门的猜测和模型。只能说，经过冷战以来美苏两极海军的不断发展和试探，海军格局最终形成了现在的模样，至于舰炮和导弹究竟孰优孰劣，其中的奥妙就任人遐想了。

### 游戏性能[编辑]

游戏中用的名称是“ASDG”。不同于现在常说的DDG，ASDG中的“AS”是“Anti-Ship”，表“反舰”之意。所以实际上游戏里的导弹驱逐舰应当是反舰导弹驱逐舰。相对地，防空导弹驱逐舰称之为“AADG”，“AA”即“Anti-Air”，表“防空”之意。现实中，一般遵照美国标准，专攻防空的驱逐舰称为“DDG”，非防空专攻的如反潜驱逐舰等仍称“DD”。

导驱有专门的导弹搭载槽，与航母的航空战攻击类似，装备了导弹的装备格会在导弹战阶段进行开幕导弹攻击，不具备导弹拦截能力。与航母一样，导驱装备了几格导弹，就对几个目标进行攻击（目标可重复），分别结算导弹伤害。而与航母不同的是，导驱和防驱必须装备发射器才能参与导弹战，而且导弹对目标进行攻击后，无论是否命中都会消耗。并且，夜战阶段如果仍有导弹余量，则夜战也进行导弹攻击；若导弹耗完，则进行炮击。反舰导弹命中极高，但伤害不及轰炸机。

因为导驱拥有开幕导弹，加上鞍山的实装使得导驱集体都增加了一个格子，再加上目前航母因防空机制修改削弱的原因，航母搭配导驱（或者潜艇和雷巡）组成的多重开幕攻击有着更好的清场效果，加上导弹拥有比鱼雷更高的命中，所以导驱目前在活动中拥有较高的实战价值。

最后注意，导驱是目前游戏内唯一被归类为主力舰的小型舰种。

战斗流程

阶段 | BUFF | 航空战 | 导弹战 | 先制反潜 | 先制鱼雷 | 炮击战·首轮炮击 | 炮击战·次轮炮击 | 鱼雷战 | 闭幕导弹 | 夜战
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否参与 | 是 | 否 | 是 | 否 | 否 | 是 | 否 | 否 | 否 | 是
备注 | 如果有的话 |  | 需要装备发射器和导弹 |  |  |  |  |  |  | 未大破才能参与，攻击方式为导弹

装备类型

装备槽数量(改前→改后)：3→3（长春为2→3）
装备种类 | 小型主炮 | 中型主炮 | 大型主炮 | 副炮 | 鱼雷 | 攻击机·战斗机·轰炸机 | 侦察机 | 雷达 | 炮弹 | 防空炮 | 反潜装备 | 发射器·导弹
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否可装备 | 是 | 否 | 否 | 否 | 否 | 否 | 否 | 是 | 否 | 是 | 否 | 是
备注 |  |  |  |  |  |  |  |  |  |  |  |
不可装备的强化部件 | 铁锚、普列塞水下防护系统、附加装甲(大型)、附加装甲(中型)

图鉴

2 4
No. 343
蔚山
2 4
No. 363
炽热
2 4
No. 401
胆大
2 5
No. 467
鞍山
5 5
No. 502
济南

改造

5 5
No. 1097
长春
2 4
No. 1343
蔚山

## 防空导弹驱逐舰 ( 防驱 ) / Destroyer, anti-air guided missile（AADG）[编辑]

### 历史沿革[编辑]

随着电子技术的发展，精确制导武器自二战末期开始登上战争舞台，而制导武器添加动力系统之后便成为导弹。导弹武器相对火炮有很多优势，导弹的命中率远高于火炮，而且导弹武器不需要复杂的反后座机构，所以威力巨大的导弹可以像鱼雷一样装备到小型军舰上。按照用途来分，可以简单分为舰舰导弹，舰空导弹，反潜导弹。视搭载军舰用途的不同，这些导弹在军舰上有不同的搭载组合，军舰同时也可以简单划分为通用，防空，反潜等军舰。而装备了导弹的驱逐舰，也顺理成章地泛称为“导弹驱逐舰”。与此同时，传统的军舰分类方法被抛弃，美国和苏联则各自发展了一套自己的分类体系。

在二战末期的防空作战中，美军开始研制用于防空的制导武器，发展到冷战初期便是著名的3T计划，最终的三款防空导弹（黄铜骑士，小猎犬，鞑靼人）涵盖了远中近各个区域，在舰队防空中各司其职。在苏联的导弹威胁出现后，防空网的重要性更加凸显，除了传统的航空攻击，她们还需要提防和拦截蜂拥而至的反舰导弹。由于西方依然保有大量火炮军舰，尤其美国海军以航母为攻防核心，而且防空导弹也具备一定的对海能力。

### 游戏性能[编辑]

游戏中用的名称是“AADG”。“AA”即“Anti-Air”，表“防空”之意不过在游戏里防驱和大巡的“防空”专指防导弹而不是“Anti-Air”指的空中的都防，防空导弹是防不了飞机的其实防空导弹提供的巨额的对空倍率和补正已经可以导致一般的航母造成不了高额伤害了。现实中，一般遵照美国标准，专攻防空的驱逐舰称为“DDG”，非防空专攻的如反潜驱逐舰等仍称“DD”。

防驱有专门的导弹搭载槽，但与导驱不一样的是，即使装备导弹防驱也无法参与导弹战阶段攻击，只会在该阶段对敌方导驱的反舰导弹进行拦截如果该阶段敌方有发射反舰导弹，但在闭幕导弹阶段可以对敌方进行攻击，和大巡的攻击模式基本一样。防驱装备了几格导弹，就对几个目标进行攻击（目标可重复），分别结算导弹伤害。而与航母不同的是，防驱必须装备发射器才能参与导弹战，而且导弹对目标进行攻击后，无论是否命中都会消耗。在鱼雷战结束后，如果仍有导弹余量，则进行闭幕导弹。夜战阶段如果仍有导弹余量，则夜战也进行导弹攻击；若导弹耗完，则进行炮击。防空导弹命中极高，但伤害不及轰炸机。

目前游戏中防驱只有基阿特一艘改造防驱，除她和格拉摩根外剩下的防驱仅能搭配一枚防空导弹，攻击频率和导弹拦截效率上都远不如大巡，目前防驱在限制大型舰同时需要对抗敌方导弹时才会考虑上场，而这种情况实在是少之又少，绝大多数时候大巡都可以做的比防驱更好，所以目前游戏内的防驱地位非常尴尬。

但由于基阿特的改造技能比较强力，在未来的活动中可以当做主力值得培养，剩下的防驱目前不推荐优先培养。

战斗流程

阶段 | BUFF | 航空战 | 导弹战 | 先制反潜 | 先制鱼雷 | 炮击战·首轮炮击 | 炮击战·次轮炮击 | 鱼雷战 | 闭幕导弹 | 夜战
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否参与 | 是 | 否 | 是 | 否 | 否 | 是 | 否 | 否 | 是 | 是
备注 | 如果有的话 |  | 需要装备发射器和导弹，但仅在对方发射开幕导弹时参与导弹拦截（且防空导弹的拦截值必须高于反舰导弹的突防值才可以拦截成功），不会攻击敌方舰船 |  |  |  |  |  | 未大破才能参与，需要装备发射器和导弹 | 未大破才能参与，攻击方式为导弹

装备类型

装备槽数量：2（格拉摩根、基阿特为3）
装备种类 | 小型主炮 | 中型主炮 | 大型主炮 | 副炮 | 鱼雷 | 攻击机·战斗机·轰炸机 | 侦察机 | 雷达 | 炮弹 | 防空炮 | 反潜装备 | 发射器·导弹
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否可装备 | 是 | 否 | 否 | 否 | 否 | 否 | 否 | 是 | 否 | 是 | 否 | 是
备注 |  |  |  |  |  |  |  |  |  |  |  |
不可装备的强化部件 | 铁锚、普列塞水下防护系统、附加装甲(大型)、附加装甲(中型)

图鉴

1 2
No. 391
查尔斯·亚当斯
3 3
No. 403
格拉摩根
2 2
No. 407
吕特晏斯

改造

4 4
No. 1094
基阿特

## 潜水艇 ( 潜艇 ) / Submarine（SS）[编辑]

### 历史沿革[编辑]

潜艇的概念早在17世纪便有人提出，但由于当时的科技水平远远不足，人们虽然已经意识到潜艇具有非凡的隐蔽性和突袭效果，但是仍然认为她们没有军事价值。步入19世纪，随着柴电动力引擎和双层船壳的发明，以及鱼雷技术的进步，潜艇的威力逐渐显现。一战中德国的“无限制潜艇战”让各国第一次感受到了来自水下的恐惧——潜艇在水下突然现身，用鱼雷重创目标后又销声匿迹。到20世纪，各国都有发展自己的潜艇，并将潜艇用于袭击商船、偷袭舰队与隐蔽侦察的行动，而在破交袭击中又以德国和美国潜艇的表现最为抢眼。战后，由于潜艇自身巨大的隐蔽性优势，各国也没有停止发展潜艇，甚至在潜艇上装上弹道导弹和核反应堆，让她们成为水下的利剑。

现实中的潜艇一般不与舰队一同行动，这点与游戏中还是挺吻合的。

### 游戏性能[编辑]

潜艇在游戏内被称作“鱼”，以鱼雷作为攻击手段，参与开幕和闭幕雷击。除了技能之外，“火力”和“对空”属性不会对潜艇产生任何影响，且潜艇的对空值无法强化，固定为0。

在游戏中，只有航战、航巡、轻母、轻巡、雷巡、驱逐这6类舰船可以攻击潜艇，除航战以外，其余5类舰船在能攻击潜艇的场合，必定会攻击潜艇。由于反潜攻击具有2.0的穿甲系数，且不受航向影响，因此潜艇在深水炸弹面前是十分脆弱的。

因为拥有开幕雷击且战斗机制过于特殊，游戏里的潜艇一般都是单独组队，很少与其他舰种混编，即使是混编一般也是与航母混编组成多重开幕以增加开幕清场效果。

潜艇因为出征消耗极低（甚至比小学生还低），而且开幕雷击可以先手攻击，所以潜艇是大多数大佬做日常周常任务的首选，在后期练一队高练度（最好满级后兼修大角度和后备弹）的潜艇是非常重要的。

自从舰队决战于2020年9月实装以后，由于潜艇刷决战的思路被开发出来，通过前期依靠快速建造潜艇刷决战来获取优质装备和主力舰船的玩法已经成为新的风潮，所以现在的潜艇不仅是大佬的玩具，也是帮助新人快速积攒实力的好帮手。

战斗流程

阶段 | BUFF | 航空战 | 导弹战 | 先制反潜 | 先制鱼雷 | 炮击战·首轮炮击 | 炮击战·次轮炮击 | 鱼雷战 | 闭幕导弹 | 夜战
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否参与 | 是 | 否 | 否 | 否 | 是 | 否 | 否 | 是 | 否 | 是
备注 | 如果有的话 |  |  |  | 需11级及以上等级且未大破 |  |  | 未大破才能参与 |  | 未大破才能参与

装备类型

装备槽数量(改前→改后)：2→3
装备种类 | 小型主炮 | 中型主炮 | 大型主炮 | 副炮 | 鱼雷 | 攻击机·战斗机·轰炸机 | 侦察机 | 雷达 | 炮弹 | 防空炮 | 反潜装备 | 发射器·导弹
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否可装备 | 否 | 否 | 否 | 否 | 是 | 否 | 否 | 否 | 否 | 否 | 否 | 否
备注 |  |  |  |  | 包括潜艇鱼雷 |  |  |  |  |  |  |
不可装备的强化部件 | 铁锚、普列塞水下防护系统、附加装甲(大型)、附加装甲(中型)、发烟筒

图鉴

6 5
No. 194
大青花鱼
6 5
No. 195
射水鱼
6 5
No. 197
U-47
6 5
No. 198
U-505
6 5
No. 289
U-81
6 5
No. 290
U-96
6 5
No. 292
U-156
6 5
No. 293
U-1206
6 5
No. 294
刺尾鱼
6 6
No. 295
S-56
6 6
No. 351
U-1405
5 5
No. 359
吕-34
4 5
No. 361
K1
4 4
No. 366
鹦鹉螺
4 4
No. 373
达·芬奇
6 5
No. 386
莉安夕
5 5
No. 402
U-35
4 5
No. 408
鲃鱼
5 5
No. 458
U-14
5 4
No. 463
鹰
2 2
No. 475
U-2511
6 5
No. 480
U-459
0 5
No. 488
U-556
2 4
No. 493
K-21
2 4
No. 497
U-441
4 4
No. 518
IIIA
2 4
No. 530
M-296
5 5
No. 538
伊-25

改造

7 6
No. 1194
大青花鱼
7 6
No. 1195
射水鱼
7 6
No. 1197
U-47
7 6
No. 1289
U-81
7 6
No. 1290
U-96
6 6
No. 1293
U-1206
7 6
No. 1351
U-1405
4 5
No. 1408
鲃鱼

## 重炮潜艇 ( 炮潜 ) / Submarine Monitor（SC）[编辑]

### 历史沿革[编辑]

“重炮潜艇”这一概念起源于一战时期，当时鱼雷的威力被认为不足以摧毁大型舰船，于是，搭载大口径舰炮的潜艇应运而生。英国的M级和法国的絮库夫号就是对这种概念的尝试，这种潜艇将作为“潜艇领舰”领导潜艇集群对商船发起攻击。但事实证明，在潜艇上搭载大口径舰炮得不偿失——且不说舰炮的性能大打折扣，连潜艇最基本的隐蔽性能也会因此损失不少。这种并不太成功的设计思路也使各国之后再也没有研究类似的潜艇。

### 游戏性能[编辑]

游戏中目前实装了3艘炮潜，英国2艘，法国1艘。常规情况下无法进行开幕雷击，但絮库夫改造后可以通过技能觉醒开幕雷击。此外由于舰种的原因，“狼群战术”的buff对炮潜无效。

炮潜可以装备重巡火炮，能在炮击战中对敌方水面舰艇进行炮击，而闭幕雷击和夜战则是鱼雷攻击，但碍于格子的限制炮潜的定位其实很尴尬，除絮库夫的技能可以将其当作潜艇来用以外，剩下的炮潜并没有开幕雷击，所以没有潜艇一样的先手优势，而如果装备重巡主炮强化炮击，格子过少也会导致其火力根本达不到重巡的水平，过于鸡肋。

最糟糕的是，炮潜与潜艇一样会被优先反潜，但炮潜因为其炮击能力，在某些场合还会响应敌人的反击类技能，导致其在生存能力不如潜艇的同时，也更容易打乱全队的节奏。加上炮潜本身高装甲高血量，修理时间也是潜艇的好几倍，实在是称不上好用，只能算潜艇的下位替换。

战斗流程

阶段 | BUFF | 航空战 | 导弹战 | 先制反潜 | 先制鱼雷 | 炮击战·首轮炮击 | 炮击战·次轮炮击 | 鱼雷战 | 闭幕导弹 | 夜战
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否参与 | 是 | 否 | 否 | 否 | 是[1] | 是 | 是 | 是 | 否 | 是
备注 | 如果有的话 |  |  |  | 满足技能生效条件且未大破 |  | 射程长或超长可参与次轮炮击 | 未大破才能参与 |  | 未大破才能参与

装备类型

装备槽数量(改前→改后)：3→3
装备种类 | 小型主炮 | 中型主炮 | 大型主炮 | 副炮 | 鱼雷 | 攻击机·战斗机·轰炸机 | 侦察机 | 雷达 | 炮弹 | 防空炮 | 反潜装备 | 发射器·导弹
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否可装备 | 是 | 是 | 否 | 否 | 是 | 否 | 否 | 否 | 否 | 否 | 否 | 否
备注 |  | 包括炮潜主炮 |  |  | 包括潜艇鱼雷 |  |  |  |  |  |  |
不可装备的强化部件 | 铁锚、普列塞水下防护系统、附加装甲(大型)、附加装甲(中型)、发烟筒

1. ↑ 絮库夫因为改造后技能“潜水巡洋舰”的效果而可以参与开幕雷击。

图鉴

4 4
No. 196
M1
4 4
No. 199
絮库夫
4 4
No. 317
M2

改造

5 5
No. 1199
絮库夫

## 补给舰 ( 补给 ) / Replenishment Oiler（AP）[编辑]

补给舰指的是字面意义上的“补给油船”，但老实说目前游戏内实装的四艘补给舰都不是真正意义上的“补给舰”——苏赫巴托尔是武装拖船，后期客串过观光游船；奥丁是海岸巡逻舰；女灶神是修理舰；托戈则当过货船、布雷舰、辅助巡洋舰和夜间战斗机引导舰，没有一艘当过补给舰……

目前游戏内补给舰只能装备部分“强化部件”。

在版本3.5.0中，女灶神这艘修理舰终于被赋予了修理技能。战舰少女有8种职业，很平衡，其中有奶妈。 “舰R八职，有奶甚衡，卜非愚者， 早已报官”

战斗流程

阶段 | BUFF | 航空战 | 导弹战 | 先制反潜 | 先制鱼雷 | 炮击战·首轮炮击 | 炮击战·次轮炮击 | 鱼雷战 | 闭幕导弹 | 夜战
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否参与 | 是 | 否 | 否 | 否 | 否 | 是 | 否 | 否 | 否 | 否
备注 | 如果有的话 |  |  |  |  |  |  |  |  |

装备类型

装备槽数量：2（女灶神、托戈为3）
装备种类 | 小型主炮 | 中型主炮 | 大型主炮 | 副炮 | 鱼雷 | 攻击机·战斗机·轰炸机 | 侦察机 | 雷达 | 炮弹 | 防空炮 | 反潜装备 | 发射器·导弹
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
是否可装备 | 否 | 否 | 否 | 否 | 否 | 否 | 否 | 否 | 否 | 否 | 否 | 否
备注 |  |  |  |  |  |  |  |  |  |  |  |
仅可装备的强化部件 | 一包辣条、标准型动力系统、改良型动力系统、先进型动力系统、附加装甲(小型)、柴油机、金块箱、 意式餐具套装、极密货物、凶猛的大老虎、"奥斯卡"、"生姜&鱼饼"、联络电台

图鉴

0 2
No. 298
苏赫巴托尔
0 2
No. 303
奥丁
0 2
No. 307
女灶神
1 2
No. 441
托戈

取自“https://www.zjsnrwiki.com/index.php?title=舰船类型&oldid=73907”
热门评论
49.94.201.164
防驱要是能拦截飞机就好了
223.104.2.155
夭寿了，u系战列舰都可以射鱼雷了
Donnyjie
模拟演习模式的出击费用
49.94.201.164
防驱要是能拦截飞机就好了
Dfsshxcrh
窝窝屎打多了的我突然回来看舰r感觉很奇妙
111.58.18.116
我是玩明白了，舰R很多图纸船都是参考wows，你游应该是最有资格跟wows联动的（结果窝窝屎眼里只有钱）
Wtniu666
大唐无双有几个职业？
113.89.221.45
左上角数字是什么来着？
Mikepa
左上角的数字分别是模拟演习和决战选择该船所需要的费用
223.104.2.155
夭寿了，u系战列舰都可以射鱼雷了
113.5.4.201
补给舰有一定几率自带小型主炮，并且可拆卸后重新安装，我的女灶神有一门炮，真的，但图片发不了
59.109.119.7
左上角的钻石????和数字是什么意思
Donnyjie
模拟演习模式的出击费用
117.136.7.194
航战仍可反潜，我用扶桑·改炸了鱼
223.104.17.208
so雷达可以使战列舰发射鱼雷
223.104.17.208
还有，so雷达可以使战列舰在白天发射鱼雷
12
返回顶部